/* 12 Exhibit 5 - Aggregate Reserve for Life Contracts.do (STATA)
	Merge different years of A.M. Best's Exhibit 5 - Aggregate Reserve for Life Contracts.
	by Motohiro Yogo */

#delimit ;
clear all;
set more off;

cap log close;
log using "12 Exhibit 5 - Aggregate Reserve for Life Contracts", replace;

/* 2002 */

u Years Companies
	Total_life_ins_rsv_gross Total_life_ins_rsv_rein_ced Total_life_ins_rsv_net
	Total_annuities_rsv_gross Total_annuities_rsv_rein_ced Total_annuities_rsv_net
	using "data\2002\13 Exhibit 8 - Aggregate Reserve for Life Contracts", clear;

save "data\12 Exhibit 5 - Aggregate Reserve for Life Contracts", replace;

/* 2003-2013 */

forval y = 2003/2013 {;
	u Years Companies
		Total_life_ins_rsv_gross Total_life_ins_rsv_rein_ced Total_life_ins_rsv_net
		Total_annuities_rsv_gross Total_annuities_rsv_rein_ced Total_annuities_rsv_net
		if Years==string(`y'-1)
		using "data\\`y'\12 Exhibit 5 - Aggregate Reserve for Life Contracts", clear;

	append using "data\12 Exhibit 5 - Aggregate Reserve for Life Contracts";

	save "data\12 Exhibit 5 - Aggregate Reserve for Life Contracts", replace;
};

/* Fix variables */

gen AMB_Number = substr(Companies,1,6);
gen AMB_Company_Name = ltrim(rtrim(itrim(substr(Companies,7,.))));

destring Years AMB_Number, replace;

replace Total_life_ins_rsv_gross = Total_life_ins_rsv_gross/1e6;
replace Total_life_ins_rsv_rein_ced = Total_life_ins_rsv_rein_ced/1e6;
replace Total_life_ins_rsv_net = Total_life_ins_rsv_net/1e6;

replace Total_annuities_rsv_gross = Total_annuities_rsv_gross/1e6;
replace Total_annuities_rsv_rein_ced = Total_annuities_rsv_rein_ced/1e6;
replace Total_annuities_rsv_net = Total_annuities_rsv_net/1e6;

drop Companies;

/* Construct variables */

merge 1:1 Years AMB_Number using "data\43 Schedule S Part 3.1.dta",
	keepusing(Rsrv_cr_cy_sep_a_c_total Coins_rsrv_sep_a_c_total);

gen rsv_gross = Total_life_ins_rsv_gross+Total_annuities_rsv_gross
	+Rsrv_cr_cy_sep_a_c_total+Coins_rsrv_sep_a_c_total;

drop Rsrv_cr_cy_sep_a_c_total Coins_rsrv_sep_a_c_total _merge;

gen LNrsv_gross = ln(rsv_gross);
gen LNlife_ins = ln(Total_life_ins_rsv_gross);
gen LNannuities = ln(Total_annuities_rsv_gross);

sort AMB_Number Years;
by AMB_Number: gen Drsv_gross = rsv_gross-rsv_gross[_n-1] if Years==Years[_n-1]+1;
by AMB_Number: gen Dlife_ins = Total_life_ins_rsv_gross-Total_life_ins_rsv_gross[_n-1] if Years==Years[_n-1]+1;
by AMB_Number: gen Dannuities = Total_annuities_rsv_gross-Total_annuities_rsv_gross[_n-1] if Years==Years[_n-1]+1;

/* Label variables */

order Years AMB_Number AMB_Company_Name;

label var Years							"Year";
label var AMB_Number					"AMB Company Number";
label var AMB_Company_Name				"AMB Company Name";

label var Total_life_ins_rsv_gross		"Total Life Insurance Reserve Gross";
label var Total_life_ins_rsv_rein_ced	"Total Life Insurance Reserve Reinsurance Ceded";
label var Total_life_ins_rsv_net		"Total Life Insurance Reserve Net";

label var Total_annuities_rsv_gross		"Total Annuities Reserve Gross";
label var Total_annuities_rsv_rein_ced	"Total Annuities Reserve Reinsurance Ceded";
label var Total_annuities_rsv_net		"Total Annuities Reserve Net";

label var rsv_gross						"Total Reserve Gross";
label var LNrsv_gross					"Log: rsv_gross"; 
label var LNlife_ins					"Log: Total_life_ins_rsv_gross";
label var LNannuities					"Log: Total_annuities_rsv_gross";
label var Drsv_gross					"Difference: rsv_gross";
label var Dlife_ins						"Difference: Total_life_ins_rsv_gross";
label var Dannuities					"Difference: Total_annuities_rsv_gross";

/* Save data */

sort Years AMB_Number;

save "data\12 Exhibit 5 - Aggregate Reserve for Life Contracts", replace;

log close;
