/* 26 Exhibit of Life Insurance (Continued).do (STATA)
	Merge different years of A.M. Best's Exhibit of Life Insurance (Continued).
	by Motohiro Yogo */

#delimit ;
clear all;
set more off;

cap log close;
log using "26 Exhibit of Life Insurance (Continued)", replace;

/* 2003 */

u "data\2003\31 Exhibit of Life Insurance (Continued)", clear;

save "data\26 Exhibit of Life Insurance (Continued)", replace;

/* 2004 */

u "data\2004\32 Exhibit of Life Insurance (Continued)"
	if Years=="2003", clear;

append using "data\26 Exhibit of Life Insurance (Continued)";

save "data\26 Exhibit of Life Insurance (Continued)", replace;

/* 2005-2008 */

forval y = 2005/2008 {;
	u "data\\`y'\27 Exhibit of Life Insurance (Continued)"
		if Years==string(`y'-1), clear;

	append using "data\26 Exhibit of Life Insurance (Continued)";

	save "data\26 Exhibit of Life Insurance (Continued)", replace;
};

/* 2009-2013 */

forval y = 2009/2013 {;
	u "data\\`y'\26 Exhibit of Life Insurance (Continued)"
		if Years==string(`y'-1), clear;

	append using "data\26 Exhibit of Life Insurance (Continued)";

	save "data\26 Exhibit of Life Insurance (Continued)", replace;
};

/* Fix variables */

gen AMB_Number = substr(Companies,1,6);
gen AMB_Company_Name = ltrim(rtrim(itrim(substr(Companies,7,.))));

destring Years AMB_Number, replace;

drop Companies;

/* Construct variables */

egen TIn_frc_end_yr_amt = sum(In_frc_end_yr_amt_total_lns_27_3), by(Years);
gen SIn_frc_end_yr_amt = 100*In_frc_end_yr_amt_total_lns_27_3/TIn_frc_end_yr_amt;

sort AMB_Number Years;
by AMB_Number: gen SIn_frc_end_yr_amt1 = SIn_frc_end_yr_amt[2] if Years[2]==1999;

drop TIn_frc_end_yr_amt;

/* Label variables */

order Years AMB_Number AMB_Company_Name;

label var Years								"Year";
label var AMB_Number						"AMB Company Number";
label var AMB_Company_Name					"AMB Company Name";

label var Iss_dr_yr_pol_total_lns_27_to_30	"Term Life Insurance - Policies Issued during Year";
label var Iss_dr_yr_pol_wh_life___endow		"Whole Life and Endowment Insurance - Policies Issued during Year";
label var Iss_dr_yr_pol_total_lns_31_to_34	"Ordinary Life Insurance - Policies Issued during Year";

label var Iss_dr_yr_amt_total_lns_27_to_30	"Term Life Insurance - Amount Issued during Year";
label var Iss_dr_yr_amt_wh_life___endow		"Whole Life and Endowment Insurance - Amount Issued during Year";
label var Iss_dr_yr_amt_total_lns_31_to_34	"Ordinary Life Insurance - Amount Issued during Year";

label var In_frc_end_yr_pol_total_lns_27_3	"Term Life Insurance - Policies in Force End of Year";
label var In_frc_end_yr_pol_wh_life___endo	"Whole Life and Endowment Insurance - Policies in Force End of Year";
label var In_frc_end_yr_pol_total_lns_31_	"Ordinary Life Insurance - Policies in Force End of Year";

label var In_frc_end_yr_amt_total_lns_27_3	"Term Life Insurance - Amount in Force End of Year";
label var In_frc_end_yr_amt_wh_life___endo	"Whole Life and Endowment Insurance - Amount in Force End of Year";
label var In_frc_end_yr_amt_total_lns_31_	"Ordinary Life Insurance - Amount in Force End of Year";

label var SIn_frc_end_yr_amt1				"In_frc_end_yr_amt_total_lns_27_3 in 1999";

/* Save data */

sort Years AMB_Number;

save "data\26 Exhibit of Life Insurance (Continued)", replace;

log close;
