/* 3 Liabilities, Surplus & Other Funds.do (STATA)
	Merge different years of A.M. Best's Liabilities, Surplus & Other Funds.
	by Motohiro Yogo */

#delimit ;
clear all;
set more off;

cap log close;
log using "3 Liabilities, Surplus & Other Funds", replace;

/* 1999 */

u Years Companies
	Aggregate_life_reserves_l_coupon Aggr_life_reserves_incl_modco__i
	Dividends_to_stkhld_decl___unpd Asset_valuation_reserve Surplus_notes
	Unassigned_funds__surplus_ Total_capital___surplus
	using "data\1999\3 Liabilities, Surplus & Other Funds", clear;

rename Aggregate_life_reserves_l_coupon Agg_resrve_for_life_contr__tot_;
rename Aggr_life_reserves_incl_modco__i Incl_coup___sim_ben_modco_rsrve_;

save "data\3 Liabilities, Surplus & Other Funds", replace;

/* 2000-2002 */

forval y = 2000/2002 {;
	u Years Companies
		Aggregate_life_reserves_l_coupon Aggr_life_reserves_incl_modco__i
		Dividends_to_stkhld_decl___unpd Asset_valuation_reserve Surplus_notes
		Unassigned_funds__surplus_ Total_capital___surplus
		if Years==string(`y'-1)
		using "data\\`y'\3 Liabilities, Surplus & Other Funds", clear;

	rename Aggregate_life_reserves_l_coupon Agg_resrve_for_life_contr__tot_;
	rename Aggr_life_reserves_incl_modco__i Incl_coup___sim_ben_modco_rsrve_;

	append using "data\3 Liabilities, Surplus & Other Funds";

	save "data\3 Liabilities, Surplus & Other Funds", replace;
};

/* 2003-2013 */

forval y = 2003/2013 {;
	u Years Companies
		Agg_resrve_for_life_contr__tot_ Incl_coup___sim_ben_modco_rsrve_
		Dividends_to_stkhld_decl___unpd Asset_valuation_reserve Surplus_notes
		Unassigned_funds__surplus_ Total_capital___surplus
		if Years==string(`y'-1)
		using "data\\`y'\3 Liabilities, Surplus & Other Funds", clear;

	append using "data\3 Liabilities, Surplus & Other Funds";

	save "data\3 Liabilities, Surplus & Other Funds", replace;
};

/* Fix variables */

gen AMB_Number = substr(Companies,1,6);
gen AMB_Company_Name = ltrim(rtrim(itrim(substr(Companies,7,.))));

destring Years AMB_Number, replace;

replace Agg_resrve_for_life_contr__tot_ = Agg_resrve_for_life_contr__tot_/1e6;
replace Incl_coup___sim_ben_modco_rsrve_ = Incl_coup___sim_ben_modco_rsrve_/1e6;

replace Dividends_to_stkhld_decl___unpd = Dividends_to_stkhld_decl___unpd/1e6;
replace Asset_valuation_reserve = Asset_valuation_reserve/1e6;
replace Surplus_notes = Surplus_notes/1e6;

replace Unassigned_funds__surplus_ = Unassigned_funds__surplus_/1e6;
replace Total_capital___surplus = Total_capital___surplus/1e6;

drop Companies;

/* Construct variables */

gen liab = max(Agg_resrve_for_life_contr__tot_-Incl_coup___sim_ben_modco_rsrve_,0);

sort AMB_Number Years;
by AMB_Number: gen Lliab = liab[_n-1] if Years==Years[_n-1]+1;

gen equity = max(Total_capital___surplus+.5*Dividends_to_stkhld_decl___unpd+Asset_valuation_reserve+Surplus_notes,0);

/* Label variables */

order Years AMB_Number AMB_Company_Name;

label var Years								"Year";
label var AMB_Number						"AMB Company Number";
label var AMB_Company_Name					"AMB Company Name";

label var Agg_resrve_for_life_contr__tot_	"Aggregate Reserve for Life Contracts";
label var Incl_coup___sim_ben_modco_rsrve_	"Including Modco Reserve";

label var Dividends_to_stkhld_decl___unpd	"Dividends to Stockholders Declared & Unpaid";
label var Asset_valuation_reserve			"Asset Valuation Reserve";
label var Surplus_notes						"Surplus Notes";

label var Unassigned_funds__surplus_		"Unassigned Funds (Surplus)";
label var Total_capital___surplus			"Total Capital & Surplus";

label var liab								"Agg_resrve_for_life_contr__tot_-Incl_coup___sim_ben_modco_rsrve_";
label var Lliab								"Lagged: liab";
label var equity							"Equity";

/* Save data */

sort Years AMB_Number;

save "data\3 Liabilities, Surplus & Other Funds", replace;

log close;
