/* 43 Schedule S Part 3.1.do (STATA)
	Merge different years of A.M. Best's Schedule S Part 3.1.
	by Motohiro Yogo */

#delimit ;
clear all;
set more off;

cap log close;
log using "43 Schedule S Part 3.1.smcl", replace;

/* 2003 */

u "data\2003\63 Schedule S Part 3.1.dta", clear;

save "data\43 Schedule S Part 3.1.dta", replace;

/* 2004 */

u "data\2004\62 Schedule S Part 3.1.dta"
	if Years=="2003", clear;

append using "data\43 Schedule S Part 3.1.dta";

save "data\43 Schedule S Part 3.1.dta", replace;

/* 2005 */

u "data\2005\57 Schedule S Part 3.1.dta"
	if Years=="2004", clear;

append using "data\43 Schedule S Part 3.1.dta";

save "data\43 Schedule S Part 3.1.dta", replace;

/* 2006 */

u "data\2006\57 Schedule S Part 3.1.dta"
	if Years=="2005", clear;

append using "data\43 Schedule S Part 3.1.dta";

rename Rsv_cr_cy_gen_a_c_total Rsrv_cr_cy_gen_a_c_total;
rename Rsv_cr_cy_sep_a_c_total Rsrv_cr_cy_sep_a_c_total;
rename Rsv_cr_cy_grand_total Rsrv_cr_cy_grand_total;

rename Rsv_cr_py_gen_a_c_total Rsrv_cr_py_gen_a_c_total;
rename Rsv_cr_py_sep_a_c_total Rsrv_cr_py_sep_a_c_total;
rename Rsv_cr_py_grand_total Rsrv_cr_py_grand_total;

rename Prems_gen_a_c_total Premiums_gen_a_c_total;
rename Prems_sep_a_c_total Premiums_sep_a_c_total;
rename Prems_grand_total Premiums_grand_total;

save "data\43 Schedule S Part 3.1.dta", replace;

/* 2007-2008 */

forval y = 2007/2008 {;
	u "data\\`y'\57 Schedule S Part 3.1.dta"
		if Years==string(`y'-1), clear;

	append using "data\43 Schedule S Part 3.1.dta";

	save "data\43 Schedule S Part 3.1.dta", replace;
};

/* 2009-2013 */

forval y = 2009/2013 {;
	u "data\\`y'\43 Schedule S Part 3.1.dta"
		if Years==string(`y'-1), clear;

	append using "data\43 Schedule S Part 3.1.dta";

	save "data\43 Schedule S Part 3.1.dta", replace;
};

/* Fix variables */

gen AMB_Number = substr(Companies,1,6);
gen AMB_Company_Name = ltrim(rtrim(itrim(substr(Companies,7,.))));

destring Years AMB_Number, replace;

replace Amt_end_yr_gen_a_c_tot_aff = 
	Amt_frc_e_yr_auth_gen_acct_affl+Amt_frc_e_yr_nauth_gen_acct_affl+min(0,Amt_frc_e_yr_cert_gen_acct_affl)
	if Years>=2006;
replace Amt_end_yr_gen_a_c_tot_non_aff = 
	Amt_frc_e_yr_auth_gen_acct_naffl+Amt_frc_e_yr_unauth_gen_acct_naf+min(0,Amt_frc_e_yr_cert_gen_acct_naffl)
	if Years>=2006;
replace Amt_end_yr_sep_a_c_tot_aff = 
	Amt_frc_e_yr_spt_accts_auth_affl+Amt_frc_e_yr_spt_accts_uath_affl+min(0,Amt_frc_e_yr_cert_sep_acct_affl)
	if Years>=2006;
replace Amt_end_yr_sep_a_c_tot_non_aff = 
	Amt_frc_e_yr_spt_accts_auth_n_af+Amt_frc_e_yr_spt_accts_uath_n_af+min(0,Amt_frc_e_yr_cert_sep_acct_naffl)
	if Years>=2006;

replace Rsv_cr_cy_gen_a_c_tot_aff = 
	Rsrv_cr_cy_auth_gen_acct_affl+Rsrv_cr_cy_unauth_gen_acct_affl+min(0,Rsrv_cr_cy_cert_gen_acct_affl)
	if Years>=2006;
replace Rsv_cr_cy_gen_a_c_tot_non_aff = 
	Rsrv_cr_cy_auth_gen_acct_non_aff+Rsrv_cr_cy_unauth_gen_acct_non_a+min(0,Rsrv_cr_cy_cert_gen_acct_naffl)
	if Years>=2006;
replace Rsv_cr_cy_sep_a_c_tot_aff =
	Rsrv_cr_cy_spt_accts_auth_affl+Rsrv_cr_cy_separate_accts_uath_a+min(0,Rsrv_cr_cy_cert_sep_acct_affl)
	if Years>=2006;
replace Rsv_cr_cy_sep_a_c_tot_non_aff =
	Rsrv_cr_cy_spt_accts_auth_n_affl+Rsrv_cr_cy_spt_accts_uath_n_affl+min(0,Rsrv_cr_cy_cert_sep_acct_naffl)
	if Years>=2006;

replace Rsv_cr_py_gen_a_c_tot_aff = 
	Rsrv_cr_py_auth_gen_acct_affl+Rsrv_cr_py_unauth_gen_acct_affl+min(0,Rsrv_cr_py_cert_gen_acct_affl)
	if Years>=2006;
replace Rsv_cr_py_gen_a_c_tot_non_aff = 
	Rsrv_cr_py_auth_gen_acct_non_aff+Rsrv_cr_py_unauth_gen_acct_non_a+min(0,Rsrv_cr_py_cert_gen_acct_naffl)
	if Years>=2006;
replace Rsv_cr_py_sep_a_c_tot_aff =
	Rsrv_cr_py_spt_accts_auth_affl+Rsrv_cr_py_separate_accts_uath_a+min(0,Rsrv_cr_py_cert_sep_acct_affl)
	if Years>=2006;
replace Rsv_cr_py_sep_a_c_tot_non_aff =
	Rsrv_cr_py_spt_accts_auth_n_affl+Rsrv_cr_py_spt_accts_uath_n_affl+min(0,Rsrv_cr_py_cert_sep_acct_naffl)
	if Years>=2006;

replace Prems_gen_a_c_tot_aff = 
	Premiums_auth_gen_acct_affl+Premiums_unauth_gen_acct_affl+min(0,Premiums_cert_gen_acct_affl)
	if Years>=2006;
replace Prems_gen_a_c_tot_non_aff = 
	Premiums_auth_gen_acct_non_affl+Premiums_unauth_gen_acct_non_aff+min(0,Premiums_cert_gen_acct_naffl)
	if Years>=2006;
replace Prems_sep_a_c_tot_aff = 
	Premiums_separate_accts_auth_aff+Premiums_separate_accts_uath_aff+min(0,Premiums_cert_sep_acct_affl)
	if Years>=2006;
replace Prems_sep_a_c_tot_non_aff =
	Premiums_separate_accts_auth_n_a+Premiums_separate_accts_uath_n_a+min(0,Premiums_cert_sep_acct_naffl)
	if Years>=2006;

replace O_s_srp_rlf_cy_gen_a_c_tot_aff =
	Cy_out_surlf_auth_gen_acct_affl+Cy_out_surlf_unauth_gen_acct_aff+min(0,Cy_out_surlf_cert_gen_acct_affl)
	if Years>=2006;
replace O_s_srp_rlf_cy_gen_a_c_tot_n_aff =
	Cy_out_surlf_auth_gen_acct_non_a+Cy_out_surlf_unauth_gen_acct_n_a+min(0,Cy_out_surlf_cert_gen_acct_naffl)
	if Years>=2006;
replace O_s_srp_rlf_cy_sep_a_c_tot_aff =
	Cy_out_surlf_sprt_accts_auth_aff+Cy_out_surlf_sprt_accts_uath_aff+min(0,Cy_out_surlf_cert_sep_acct_affl)
	if Years>=2006;
replace O_s_srp_rlf_cy_sep_a_c_tot_n_aff =
	Cy_out_surlf_sprt_accts_auth_n_a+Cy_out_surlf_sprt_accts_uath_n_a+min(0,Cy_out_surlf_cert_sep_acct_naffl)
	if Years>=2006;

replace O_s_srp_rlf_py_gen_a_c_tot_aff =
	Py_out_surlf_auth_gen_acct_affl+Py_out_surlf_unauth_gen_acct_aff+min(0,Py_out_surlf_cert_gen_acct_affl)
	if Years>=2006;
replace O_s_srp_rlf_py_gen_a_c_tot_n_aff =
	Py_out_surlf_auth_gen_acct_non_a+Py_out_surlf_unauth_gen_acct_n_a+min(0,Py_out_surlf_cert_gen_acct_naffl)
	if Years>=2006;
replace O_s_srp_rlf_py_sep_a_c_tot_aff =
	Py_out_surlf_sprt_accts_auth_aff+Py_out_surlf_sprt_accts_uath_aff+min(0,Py_out_surlf_cert_sep_acct_affl)
	if Years>=2006;
replace O_s_srp_rlf_py_sep_a_c_tot_n_aff =
	Py_out_surlf_sprt_accts_auth_n_a+Py_out_surlf_sprt_accts_uath_n_a+min(0,Cy_out_surlf_cert_sep_acct_naffl)
	if Years>=2006;

replace Coins_rsrv_gen_a_c_tot_aff = 
	Mod_co_re_auth_gen_acct_affl+Mod_co_re_unauth_gen_acct_affl+min(0,Mod_co_re_cert_gen_acct_affl)
	if Years>=2006;
replace Coins_rsrv_gen_a_c_tot_non_aff =
	Mod_co_re_auth_gen_acct_non_affl+Mod_co_re_unauth_gen_acct_non_af+min(0,Mod_co_re_cert_gen_acct_naffl)
	if Years>=2006;
replace Coins_rsrv_sep_a_c_tot_aff = 
	Mod_co_re_sprt_accts_auth_affl+Mod_co_re_sprt_accts_uath_affl+min(0,Mod_co_re_sprt_accts_cert_affl)
	if Years>=2006;
replace Coins_rsrv_sep_a_c_tot_non_aff =
	Mod_co_re_sprt_accts_auth_n_afl+Mod_co_re_sprt_accts_uath_n_afl+min(0,Mod_co_re_sprt_accts_cert_naffl)
	if Years>=2006;

replace W_held_fnds_gen_a_c_tot_aff =
	Whld_uco_auth_gen_acct_affl+Whld_uco_unauth_gen_acct_affl+min(0,Whld_uco_cert_gen_acct_affl)
	if Years>=2006;
replace W_held_fnds_gen_a_c_tot_non_aff =
	Whld_uco_auth_gen_acct_non_affl+Whld_uco_unauth_gen_acct_non_aff+min(0,Whld_uco_cert_gen_acct_naffl)
	if Years>=2006;
replace W_held_fnds_sep_a_c_tot_aff =
	Whld_uco_separate_accts_auth_aff+Whld_uco_separate_accts_uath_aff+min(0,Whld_uco_separate_accts_cert_aff)
	if Years>=2006;
replace W_held_fnds_sep_a_c_tot_non_aff =
	Whld_uco_separate_accts_auth_n_a+Whld_uco_separate_accts_uath_n_a+min(0,Whld_uco_separate_accts_cert_una)
	if Years>=2006;

replace Rsrv_cr_cy_auth_gen_acct_affl = Rsrv_cr_cy_auth_gen_acct_affl/1e6;
replace Rsrv_cr_cy_auth_gen_acct_non_aff = Rsrv_cr_cy_auth_gen_acct_non_aff/1e6;
replace Rsrv_cr_cy_auth_gen_acct_total = Rsrv_cr_cy_auth_gen_acct_total/1e6;
replace Rsrv_cr_cy_unauth_gen_acct_affl = Rsrv_cr_cy_unauth_gen_acct_affl/1e6;
replace Rsrv_cr_cy_unauth_gen_acct_non_a = Rsrv_cr_cy_unauth_gen_acct_non_a/1e6;
replace Rsrv_cr_cy_unauth_gen_acct_total = Rsrv_cr_cy_unauth_gen_acct_total/1e6;
replace Rsrv_cr_cy_cert_gen_acct_affl = Rsrv_cr_cy_cert_gen_acct_affl/1e6;
replace Rsrv_cr_cy_cert_gen_acct_naffl = Rsrv_cr_cy_cert_gen_acct_naffl/1e6;
replace Rsrv_cr_cy_cert_gen_acct_ttl = Rsrv_cr_cy_cert_gen_acct_ttl/1e6;
replace Rsrv_cr_cy_gen_a_c_total = Rsrv_cr_cy_gen_a_c_total/1e6;
replace Rsrv_cr_cy_spt_accts_auth_affl = Rsrv_cr_cy_spt_accts_auth_affl/1e6;
replace Rsrv_cr_cy_spt_accts_auth_n_affl = Rsrv_cr_cy_spt_accts_auth_n_affl/1e6;
replace Rsrv_cr_cy_separate_accts_auth = Rsrv_cr_cy_separate_accts_auth/1e6;
replace Rsrv_cr_cy_separate_accts_uath_a = Rsrv_cr_cy_separate_accts_uath_a/1e6;
replace Rsrv_cr_cy_spt_accts_uath_n_affl = Rsrv_cr_cy_spt_accts_uath_n_affl/1e6;
replace Rsrv_cr_cy_separate_accts_uath = Rsrv_cr_cy_separate_accts_uath/1e6;
replace Rsrv_cr_cy_cert_sep_acct_affl = Rsrv_cr_cy_cert_sep_acct_affl/1e6;
replace Rsrv_cr_cy_cert_sep_acct_naffl = Rsrv_cr_cy_cert_sep_acct_naffl/1e6;
replace Rsrv_cr_cy_cert_sep_acct_ttl = Rsrv_cr_cy_cert_sep_acct_ttl/1e6;
replace Rsrv_cr_cy_sep_a_c_total = Rsrv_cr_cy_sep_a_c_total/1e6;
replace Rsrv_cr_cy_grand_total = Rsrv_cr_cy_grand_total/1e6;

replace Rsrv_cr_py_auth_gen_acct_affl = Rsrv_cr_py_auth_gen_acct_affl/1e6;
replace Rsrv_cr_py_auth_gen_acct_non_aff = Rsrv_cr_py_auth_gen_acct_non_aff/1e6;
replace Rsrv_cr_py_auth_gen_acct_total = Rsrv_cr_py_auth_gen_acct_total/1e6;
replace Rsrv_cr_py_unauth_gen_acct_affl = Rsrv_cr_py_unauth_gen_acct_affl/1e6;
replace Rsrv_cr_py_unauth_gen_acct_non_a = Rsrv_cr_py_unauth_gen_acct_non_a/1e6;
replace Rsrv_cr_py_unauth_gen_acct_total = Rsrv_cr_py_unauth_gen_acct_total/1e6;
replace Rsrv_cr_py_cert_gen_acct_affl = Rsrv_cr_py_cert_gen_acct_affl/1e6;
replace Rsrv_cr_py_cert_gen_acct_naffl = Rsrv_cr_py_cert_gen_acct_naffl/1e6;
replace Rsrv_cr_py_cert_gen_acct_ttl = Rsrv_cr_py_cert_gen_acct_ttl/1e6;
replace Rsrv_cr_py_gen_a_c_total = Rsrv_cr_py_gen_a_c_total/1e6;
replace Rsrv_cr_py_spt_accts_auth_affl = Rsrv_cr_py_spt_accts_auth_affl/1e6;
replace Rsrv_cr_py_spt_accts_auth_n_affl = Rsrv_cr_py_spt_accts_auth_n_affl/1e6;
replace Rsrv_cr_py_separate_accts_auth = Rsrv_cr_py_separate_accts_auth/1e6;
replace Rsrv_cr_py_separate_accts_uath_a = Rsrv_cr_py_separate_accts_uath_a/1e6;
replace Rsrv_cr_py_spt_accts_uath_n_affl = Rsrv_cr_py_spt_accts_uath_n_affl/1e6;
replace Rsrv_cr_py_separate_accts_uath = Rsrv_cr_py_separate_accts_uath/1e6;
replace Rsrv_cr_py_cert_sep_acct_affl = Rsrv_cr_py_cert_sep_acct_affl/1e6;
replace Rsrv_cr_py_cert_sep_acct_naffl = Rsrv_cr_py_cert_sep_acct_naffl/1e6;
replace Rsrv_cr_py_cert_sep_acct_ttl = Rsrv_cr_py_cert_sep_acct_ttl/1e6;
replace Rsrv_cr_py_sep_a_c_total = Rsrv_cr_py_sep_a_c_total/1e6;
replace Rsrv_cr_py_grand_total = Rsrv_cr_py_grand_total/1e6;

replace Rsv_cr_cy_gen_a_c_tot_aff = Rsv_cr_cy_gen_a_c_tot_aff/1e6;
replace Rsv_cr_cy_gen_a_c_tot_non_aff = Rsv_cr_cy_gen_a_c_tot_non_aff/1e6;
replace Rsv_cr_cy_sep_a_c_tot_aff = Rsv_cr_cy_sep_a_c_tot_aff/1e6;
replace Rsv_cr_cy_sep_a_c_tot_non_aff = Rsv_cr_cy_sep_a_c_tot_non_aff/1e6;
replace Rsv_cr_py_gen_a_c_tot_aff = Rsv_cr_py_gen_a_c_tot_aff/1e6;
replace Rsv_cr_py_gen_a_c_tot_non_aff = Rsv_cr_py_gen_a_c_tot_non_aff/1e6;
replace Rsv_cr_py_sep_a_c_tot_aff = Rsv_cr_py_sep_a_c_tot_aff/1e6;
replace Rsv_cr_py_sep_a_c_tot_non_aff = Rsv_cr_py_sep_a_c_tot_non_aff/1e6;

replace Mod_co_re_auth_gen_acct_affl = Mod_co_re_auth_gen_acct_affl/1e6;
replace Mod_co_re_auth_gen_acct_non_affl = Mod_co_re_auth_gen_acct_non_affl/1e6;
replace Mod_co_re_auth_gen_acct_total = Mod_co_re_auth_gen_acct_total/1e6;
replace Mod_co_re_unauth_gen_acct_affl = Mod_co_re_unauth_gen_acct_affl/1e6;
replace Mod_co_re_unauth_gen_acct_non_af = Mod_co_re_unauth_gen_acct_non_af/1e6;
replace Mod_co_re_unauth_gen_acct_total = Mod_co_re_unauth_gen_acct_total/1e6;
replace Mod_co_re_cert_gen_acct_affl = Mod_co_re_cert_gen_acct_affl/1e6;
replace Mod_co_re_cert_gen_acct_naffl = Mod_co_re_cert_gen_acct_naffl/1e6;
replace Mod_co_re_cert_gen_acct_ttl = Mod_co_re_cert_gen_acct_ttl/1e6;
replace Coins_rsrv_gen_a_c_total = Coins_rsrv_gen_a_c_total/1e6;
replace Mod_co_re_sprt_accts_auth_affl = Mod_co_re_sprt_accts_auth_affl/1e6;
replace Mod_co_re_sprt_accts_auth_n_afl = Mod_co_re_sprt_accts_auth_n_afl/1e6;
replace Mod_co_re_sprt_accts_auth = Mod_co_re_sprt_accts_auth/1e6;
replace Mod_co_re_sprt_accts_uath_affl = Mod_co_re_sprt_accts_uath_affl/1e6;
replace Mod_co_re_sprt_accts_uath_n_afl = Mod_co_re_sprt_accts_uath_n_afl/1e6;
replace Mod_co_re_sprt_accts_uath = Mod_co_re_sprt_accts_uath/1e6;
replace Mod_co_re_sprt_accts_cert_affl = Mod_co_re_sprt_accts_cert_affl/1e6;
replace Mod_co_re_sprt_accts_cert_naffl = Mod_co_re_sprt_accts_cert_naffl/1e6;
replace Mod_co_re_sprt_accts_cert_ttl = Mod_co_re_sprt_accts_cert_ttl/1e6;
replace Coins_rsrv_sep_a_c_total = Coins_rsrv_sep_a_c_total/1e6;
replace Coins_rsrv_grand_total = Coins_rsrv_grand_total/1e6;

replace Coins_rsrv_gen_a_c_tot_aff = Coins_rsrv_gen_a_c_tot_aff/1e6;
replace Coins_rsrv_gen_a_c_tot_non_aff = Coins_rsrv_gen_a_c_tot_non_aff/1e6;
replace Coins_rsrv_sep_a_c_tot_aff = Coins_rsrv_sep_a_c_tot_aff/1e6;
replace Coins_rsrv_sep_a_c_tot_non_aff = Coins_rsrv_sep_a_c_tot_non_aff/1e6;

drop Companies;

/* Label variables */

order Years AMB_Number AMB_Company_Name;

label var Years			 	"Year";
label var AMB_Number		"AMB Company Number";
label var AMB_Company_Name	"AMB Company Name";

/* Save data */

sort Years AMB_Number;

save "data\43 Schedule S Part 3.1.dta", replace;

log close;
