/* 47 Schedule S Part 6.do (STATA)
	Merge different years of A.M. Best's Schedule S Part 6.
	by Motohiro Yogo */

#delimit ;
clear all;
set more off;

cap log close;
log using "47 Schedule S Part 6", replace;

/* 2003 */

u Years Companies
	As_rep_total_assets_excl_sep_acc As_reported_total_assets As_rep_tot_liabs_excl_sep_accoun As_reported_total_liabilities As_rep_capital___surplus
	Rs_adjustments_total_assets Rs_adj_tot_liabs_excl_sep_accoun Rs_adjustments_total_liabilities
	Restate_total_assets_excl_sep_ac Restated_total_assets Restate_tot_liabs_excl_sep_accou Restated_total_liabilities
	using "data\2003\67 Schedule S Part 6", clear;

save "data\47 Schedule S Part 6", replace;

/* 2004 */

u Years Companies
	As_rep_total_assets_excl_sep_acc As_reported_total_assets As_rep_tot_liabs_excl_sep_accoun As_reported_total_liabilities As_rep_capital___surplus
	Rs_adjustments_total_assets Rs_adj_tot_liabs_excl_sep_accoun Rs_adjustments_total_liabilities
	Restate_total_assets_excl_sep_ac Restated_total_assets Restate_tot_liabs_excl_sep_accou Restated_total_liabilities
	if Years=="2003"
	using "data\2004\66 Schedule S Part 6", clear;

append using "data\47 Schedule S Part 6";

save "data\47 Schedule S Part 6", replace;

/* 2005-2008 */

forval y = 2005/2008 {;
	u Years Companies
		As_rep_total_assets_excl_sep_acc As_reported_total_assets As_rep_tot_liabs_excl_sep_accoun As_reported_total_liabilities As_rep_capital___surplus
		Rs_adjustments_total_assets Rs_adj_tot_liabs_excl_sep_accoun Rs_adjustments_total_liabilities
		Restate_total_assets_excl_sep_ac Restated_total_assets Restate_tot_liabs_excl_sep_accou Restated_total_liabilities
		if Years==string(`y'-1)
		using "data\\`y'\61 Schedule S Part 6", clear;

	append using "data\47 Schedule S Part 6";

	save "data\47 Schedule S Part 6", replace;
};

/* 2009-2012 */

forval y = 2009/2012 {;
	u Years Companies
		As_rep_total_assets_excl_sep_acc As_reported_total_assets As_rep_tot_liabs_excl_sep_accoun As_reported_total_liabilities As_rep_capital___surplus
		Rs_adjustments_total_assets Rs_adj_tot_liabs_excl_sep_accoun Rs_adjustments_total_liabilities
		Restate_total_assets_excl_sep_ac Restated_total_assets Restate_tot_liabs_excl_sep_accou Restated_total_liabilities
		if Years==string(`y'-1)
		using "data\\`y'\47 Schedule S Part 6", clear;

	append using "data\47 Schedule S Part 6";

	save "data\47 Schedule S Part 6", replace;
};

/* 2013 */

u Years Companies
	As_rep_total_assets_excl_sep_acc As_reported_total_assets As_rep_tot_liabs_excl_sep_accoun As_reported_total_liabilities As_rep_capital___surplus
	Rs_adjustments_total_assets Rs_adj_tot_liabs_excl_sep_accoun Rs_adjustments_total_liabilities
	Restate_total_assets_excl_sep_ac Restated_total_assets Restate_tot_liabs_excl_sep_accou Restated_total_liabilities
	if Years=="2012"
	using "data\2013\49 Schedule S Part 7", clear;

append using "data\47 Schedule S Part 6";

save "data\47 Schedule S Part 6", replace;

/* Fix variables */

gen AMB_Number = substr(Companies,1,6);
gen AMB_Company_Name = ltrim(rtrim(itrim(substr(Companies,7,.))));

destring Years AMB_Number, replace;

replace As_rep_total_assets_excl_sep_acc = As_rep_total_assets_excl_sep_acc/1e6;
replace As_reported_total_assets = As_reported_total_assets/1e6;
replace As_rep_tot_liabs_excl_sep_accoun = As_rep_tot_liabs_excl_sep_accoun/1e6;
replace	As_reported_total_liabilities = As_reported_total_liabilities/1e6;
replace As_rep_capital___surplus = As_rep_capital___surplus/1e6;

replace Rs_adjustments_total_assets = Rs_adjustments_total_assets/1e6;
replace Rs_adj_tot_liabs_excl_sep_accoun = Rs_adj_tot_liabs_excl_sep_accoun/1e6;
replace Rs_adjustments_total_liabilities = Rs_adjustments_total_liabilities/1e6;

replace Restate_total_assets_excl_sep_ac = Restate_total_assets_excl_sep_ac/1e6;
replace Restated_total_assets = Restated_total_assets/1e6;
replace Restate_tot_liabs_excl_sep_accou = Restate_tot_liabs_excl_sep_accou/1e6;
replace Restated_total_liabilities = Restated_total_liabilities/1e6;

drop Companies;

/* Construct variables */

gen LNassets = ln(As_reported_total_assets);
gen LNliabilities = ln(As_reported_total_liabilities);
gen LNcapital = ln(As_rep_capital___surplus);

gen leverage = 100*As_reported_total_liabilities/As_reported_total_assets;

/* Label variables */

order Years AMB_Number AMB_Company_Name;

label var Years								"Year";
label var AMB_Number						"AMB Company Number";
label var AMB_Company_Name					"AMB Company Name";

label var As_rep_total_assets_excl_sep_acc	"As Reported: Total Assets Excluding Separate Accounts";
label var As_reported_total_assets			"As Reported: Total Assets";
label var As_rep_tot_liabs_excl_sep_accoun	"As Reported: Total Liabilities Excluding Separate Accounts";
label var As_reported_total_liabilities		"As Reported: Total Liabilities";
label var As_rep_capital___surplus			"As Reported: Capital & Surplus";

label var Rs_adjustments_total_assets		"Restatement Adjustments: Total Assets";
label var Rs_adj_tot_liabs_excl_sep_accoun	"Restatement Adjustments: Total Liabilities Excluding Separate Accounts";
label var Rs_adjustments_total_liabilities	"Restatement Adjustments: Total Liabilities";

label var Restate_total_assets_excl_sep_ac	"Restated: Total Assets Excluding Separate Accounts";
label var Restated_total_assets				"Restated: Total Assets";
label var Restate_tot_liabs_excl_sep_accou	"Restated: Total Liabilities Excluding Separate Accounts";
label var Restated_total_liabilities		"Restated: Total Liabilities";

label var LNassets							"Log: As_reported_total_assets";
label var LNliabilities						"Log: As_reported_total_liabilities";
label var LNcapital							"Log: As_rep_capital___surplus";
label var leverage							"As_reported_total_liabilities/As_reported_total_assets";

/* Save data */

sort Years AMB_Number;

save "data\47 Schedule S Part 6", replace;

log close;
