/* All General Information.do (STATA)
	Merge different years of A.M. Best's All General Information.
	by Motohiro Yogo */

#delimit ;
clear all;
set more off;

cap log close;
log using "All General Information", replace;

/* 1999 */

u Years
	Amb_company_number Company_name Amb_group_number Group_name
	Aggregation_code State_of_domicile Market_code Organization_code
	Naic_company_number Naic_group_number Federal_employer_id_number
	Current_best_s_rating Current_financial_size_code
	if Years=="1998"
	using "data\1999\General Information", clear;

tostring Amb_company_number Amb_group_number Naic_company_number Naic_group_number, replace;

save "data\All General Information", replace;

/* 2000 */

u Years
	Amb_company_number Company_name Amb_group_number Group_name
	Aggregation_code State_of_domicile Market_code Organization_code
	Naic_company_number Naic_group_number Federal_employer_id_number
	Current_best_s_rating Current_financial_size_code
	if Years=="1999"
	using "data\2000\General Information", clear;
	
append using "data\All General Information";

tostring Aggregation_code, replace;

replace Aggregation_code = "C" if Aggregation_code=="0";
replace Aggregation_code = "A" if Aggregation_code=="1";
replace Aggregation_code = "U" if Aggregation_code=="2";
replace Aggregation_code = "G" if Aggregation_code=="3";
replace Aggregation_code = "T" if Aggregation_code=="4";

save "data\All General Information", replace;

/* 2001 */

u Years
	Amb_company_number Company_name Amb_group_number Group_name
	Aggregation_code State_of_domicile Market_code Organization_code
	Naic_company_number Naic_group_number Federal_employer_id_number
	Current_best_s_rating Current_financial_size_code A2000_best_s_capital_adequacy_ra
	if Years=="2000"
	using "data\2001\General Information", clear;

rename A2000_best_s_capital_adequacy_ra Best_s_Capital_Adequacy_Ratio;

append using "data\All General Information";

save "data\All General Information", replace;

/* 2002 */

u Years
	Amb_company_number Company_name Amb_group_number Group_name
	Aggregation_code State_of_domicile Market_code Organization_code
	Naic_company_number Naic_group_number Federal_employer_id_number
	Current_best_s_rating Current_financial_size_code A2001_best_s_capital_adequacy_ra
	if Years=="2001"
	using "data\2002\General Information", clear;

rename A2001_best_s_capital_adequacy_ra Best_s_Capital_Adequacy_Ratio;

append using "data\All General Information";

rename Amb_company_number A_M__Best_Company_Number;
rename Company_name A_M__Best_Company_Name;
rename Amb_group_number A_M__Best_Group_Number;
rename Group_name A_M__Best_Group_Name;
rename Aggregation_code Aggregation_Code;
rename State_of_domicile State_of_Domicile;
rename Market_code Marketing_Type;
rename Organization_code Organization_Type;
rename Naic_company_number NAIC_Company_Number;
rename Naic_group_number NAIC_Group_Number;
rename Federal_employer_id_number Federal_Employer_ID_Number;
rename Current_best_s_rating Current_Best_s_Rating;
rename Current_financial_size_code Financial_Size_Category_Code;

save "data\All General Information", replace;

/* 2003 */

u Years
	A_M__Best_Company_Number A_M__Best_Company_Name A_M__Best_Group_Number A_M__Best_Group_Name
	Aggregation_Code State_of_Domicile Marketing_Type Organization_Type
	NAIC_Company_Number NAIC_Group_Number Federal_Employer_ID_Number
	Current_Best_s_Rating Financial_Size_Category_Code A2002_Best_s_Capital_Adequacy_Ra
	if Years=="2002"
	using "data\2003\General Information", clear;

rename A2002_Best_s_Capital_Adequacy_Ra Best_s_Capital_Adequacy_Ratio;

append using "data\All General Information";

rename Current_Best_s_Rating Best_s_Rating___Current;

save "data\All General Information", replace;

/* 2004-2008 */

forval y = 2004/2008 {;
	u Years
		A_M__Best_Company_Number A_M__Best_Company_Name A_M__Best_Group_Number A_M__Best_Group_Name
		Aggregation_Code State_of_Domicile Marketing_Type Organization_Type
		NAIC_Company_Number NAIC_Group_Number Federal_Employer_ID_Number
		Best_s_Rating___Current Financial_Size_Category_Code A`=`y'-1'_Best_s_Capital_Adequacy_Ra
		if Years==string(`y'-1)
		using "data\\`y'\General Information", clear;

	rename A`=`y'-1'_Best_s_Capital_Adequacy_Ra Best_s_Capital_Adequacy_Ratio;

	append using "data\All General Information";

	save "data\All General Information", replace;
};

/* 2009 */

u Years
	A_M__Best_Company_Number A_M__Best_Company_Name A_M__Best_Group_Number A_M__Best_Group_Name
	Aggregation_Code State_of_Domicile Marketing_Type Organization_Type
	NAIC_Company_Number NAIC_Group_Number Federal_Employer_ID_Number
	Best_s_Rating___Current Financial_Size_Category_Code A2008_Best_s_Capital_Adequacy_Ra
	if Years=="2008"
	using "data\2009\General Information", clear;

rename A2008_Best_s_Capital_Adequacy_Ra Best_s_Capital_Adequacy_Ratio;

append using "data\All General Information";

rename A_M__Best_Company_Number AMB_Number;
rename A_M__Best_Company_Name AMB_Company_Name;
rename A_M__Best_Group_Number AMB_Financial_Group_Number;
rename A_M__Best_Group_Name AMB_Financial_Group_Name;
rename Best_s_Rating___Current Best_s_FSR___Current;

save "data\All General Information", replace;

/* 2010 */

u Years Companies
	AMB_Number AMB_Company_Name AMB_Financial_Group_Number AMB_Financial_Group_Name
	Aggregation_Code Marketing_Type Organization_Type
	NAIC_Company_Number NAIC_Group_Number Federal_Employer_ID_Number
	Best_s_FSR___Current Financial_Size_Category_Code A2009_Best_s_Capital_Adequacy_Ra
	if Years=="2009"
	using "data\2010\General Information", clear;

merge 1:1 Years Companies using "data\2010\Address and Contact",
	keepusing(State_of_Domicile);

keep if _merge==3;
drop Companies _merge;

rename A2009_Best_s_Capital_Adequacy_Ra Best_s_Capital_Adequacy_Ratio;

append using "data\All General Information";

save "data\All General Information", replace;

/* 2011 */

u Years Companies
	AMB_Number AMB_Company_Name AMB_Financial_Group_Number AMB_Financial_Group_Name
	Aggregation_Code Marketing_Type Organization_Type
	NAIC_Company_Number NAIC_Group_Number Federal_Employer_ID_Number
	Best_s_FSR___Current Financial_Size_Category_Code Best_s_Capital_Adequacy_Ratio
	if Years=="2010"
	using "data\2011\General Information", clear;

merge 1:1 Years Companies using "data\2011\Address and Contact",
	keepusing(State_of_Domicile);

keep if _merge==3;
drop Companies _merge;

append using "data\All General Information";

save "data\All General Information", replace;

/* 2012-2013 */

forval y = 2012/2013 {;
	u Years
		AMB_Number AMB_Company_Name AMB_Financial_Group_Number AMB_Financial_Group_Name
		Aggregation_Code State_of_Domicile Marketing_Type Organization_Type
		NAIC_Company_Number NAIC_Group_Number Federal_Employer_ID_Number
		Best_s_FSR___Current Financial_Size_Category_Code Best_s_Capital_Adequacy_Ratio
		if Years==string(`y'-1)
		using "data\\`y'\All General Information", clear;

	append using "data\All General Information";

	save "data\All General Information", replace;
};

/* Fix variables */

destring Years AMB_Number AMB_Financial_Group_Number NAIC_Company_Number NAIC_Group_Number, replace;

recode AMB_Financial_Group_Number NAIC_Company_Number NAIC_Group_Number (0=.);

replace AMB_Financial_Group_Name = AMB_Company_Name if AMB_Financial_Group_Name=="" & Aggregation_Code=="U";
replace AMB_Financial_Group_Number = AMB_Number if AMB_Financial_Group_Number==. & Aggregation_Code=="U";

replace Best_s_FSR___Current = rtrim(regexr(Best_s_FSR___Current,"(gu|pd|pu|ru|g|p|r|s|u|-[1-5]|\.\.\.)$",""));
replace Best_s_FSR___Current = regexr(Best_s_FSR___Current,"^$","NR");
replace Best_s_FSR___Current = regexr(Best_s_FSR___Current,"FPR 9","A+");
replace Best_s_FSR___Current = regexr(Best_s_FSR___Current,"FPR 8","A");
replace Best_s_FSR___Current = regexr(Best_s_FSR___Current,"FPR 7","A-");
replace Best_s_FSR___Current = regexr(Best_s_FSR___Current,"FPR 6","B++");
replace Best_s_FSR___Current = regexr(Best_s_FSR___Current,"FPR 5","B+");
replace Best_s_FSR___Current = regexr(Best_s_FSR___Current,"FPR 4","B");
replace Best_s_FSR___Current = regexr(Best_s_FSR___Current,"FPR 3","C++");
replace Best_s_FSR___Current = regexr(Best_s_FSR___Current,"FPR 2","C");
replace Best_s_FSR___Current = regexr(Best_s_FSR___Current,"FPR 1","D");

replace State = regexr(State,"AL","Alabama");
replace State = regexr(State,"AR","Arkansas");
replace State = regexr(State,"AZ","Arizona");
replace State = regexr(State,"CA","California");
replace State = regexr(State,"CN","Canada");
replace State = regexr(State,"CO","Colorado");
replace State = regexr(State,"CT","Connecticut");
replace State = regexr(State,"DC","District of Columbia");
replace State = regexr(State,"DE","Delaware");
replace State = regexr(State,"FL","Florida");
replace State = regexr(State,"GA","Georgia");
replace State = regexr(State,"GU","Guam");
replace State = regexr(State,"HI","Hawaii");
replace State = regexr(State,"IA","Iowa");
replace State = regexr(State,"ID","Idaho");
replace State = regexr(State,"IL","Illinois");
replace State = regexr(State,"IN","Indiana");
replace State = regexr(State,"KS","Kansas");
replace State = regexr(State,"KY","Kentucky");
replace State = regexr(State,"LA","Louisiana");
replace State = regexr(State,"MA","Massachusetts");
replace State = regexr(State,"MD","Maryland");
replace State = regexr(State,"ME","Maine");
replace State = regexr(State,"MI","Michigan");
replace State = regexr(State,"MN","Minnesota");
replace State = regexr(State,"MO","Missouri");
replace State = regexr(State,"MS","Mississippi");
replace State = regexr(State,"MT","Montana");
replace State = regexr(State,"NC","North Carolina");
replace State = regexr(State,"ND","North Dakota");
replace State = regexr(State,"NE","Nebraska");
replace State = regexr(State,"NH","New Hampshire");
replace State = regexr(State,"NJ","New Jersey");
replace State = regexr(State,"NM","New Mexico");
replace State = regexr(State,"NV","Nevada");
replace State = regexr(State,"NY","New York");
replace State = regexr(State,"OH","Ohio");
replace State = regexr(State,"OK","Oklahoma");
replace State = regexr(State,"OR","Oregon");
replace State = regexr(State,"PA","Pennsylvania");
replace State = regexr(State,"PR","Puerto Rico");
replace State = regexr(State,"RI","Rhode Island");
replace State = regexr(State,"SC","South Carolina");
replace State = regexr(State,"SD","South Dakota");
replace State = regexr(State,"TN","Tennessee");
replace State = regexr(State,"TX","Texas");
replace State = regexr(State,"UT","Utah");
replace State = regexr(State,"VA","Virginia");
replace State = regexr(State,"VT","Vermont");
replace State = regexr(State,"WA","Washington");
replace State = regexr(State,"WI","Wisconsin");
replace State = regexr(State,"WV","West Virginia");
replace State = regexr(State,"WY","Wyoming");

/* Construct variables */

gen byte stock = regexm(Organization_Type,"S");

sort AMB_Number Years;
by AMB_Number: gen byte stock1 = stock[1] if Years[1]==1999;
by AMB_Number: replace stock1 = stock[2] if Years[2]==1999;

/* Label variables */

label var Years							"Year";
label var AMB_Number					"AMB Company Number";
label var AMB_Company_Name				"AMB Company Name";
label var AMB_Financial_Group_Number	"AMB Financial Group Number";
label var AMB_Financial_Group_Name		"AMB Financial Group Name";

label var Aggregation_Code				"Aggregation Code";
label var State_of_Domicile				"State of Domicile";
label var Marketing_Type				"Marketing Type";
label var Organization_Type				"Organization Type";

label var NAIC_Company_Number			"NAIC Company Number";
label var NAIC_Group_Number				"NAIC Group Number";
label var Federal_Employer_ID_Number	"Federal Employer ID Number";

label var Best_s_FSR___Current			"Best's Financial Strength Rating - Current";
label var Financial_Size_Category_Code	"Best's Financial Size Category Code";
label var Best_s_Capital_Adequacy_Ratio	"Best's Capital Adequacy Ratio";

label var stock							"Dummy: Stock company";
label var stock1						"Dummy: Stock company in 1999";

/* Save data */

sort Years AMB_Number;

save "data\All General Information", replace;

log close;
