/* Liquidity Analysis.do (STATA)
	Merge different years of A.M. Best's Liquidity Analysis.
	by Motohiro Yogo */

#delimit ;
clear all;
set more off;

cap log close;
log using "Liquidity Analysis", replace;

/* 2003 */

u "data\2003\Liquidity Analysis", clear;

save "data\Liquidity Analysis", replace;

/* 2004-2013 */

forval y = 2004/2013 {;
	u "data\\`y'\Liquidity Analysis"
		if Years==string(`y'-1), clear;

	append using "data\Liquidity Analysis";

	save "data\Liquidity Analysis", replace;
};

/* Fix variables */

gen AMB_Number = substr(Companies,1,6);
gen AMB_Company_Name = ltrim(rtrim(itrim(substr(Companies,7,.))));

destring Years AMB_Number, replace;

drop Companies;

/* Label variables */

order Years AMB_Number AMB_Company_Name;

label var Years								"Year";
label var AMB_Number						"AMB Company Number";
label var AMB_Company_Name					"AMB Company Name";

label var Operating_cash_flow				"Operating Cash Flow";
label var Quick_liquidity					"Quick Liquidity";
label var Current_liquidity					"Current Liquidity";
label var Non_inv_grade_bonds_to_capital	"Non Investment-Grade Bonds to Capital";
label var Del___foreclosed_mtgs_to_capital	"Delinquent & Foreclosed Mortgages to Capital";
label var Mortgage___real_estate_to_capita	"Mortgage & Real Estate to Capital";
label var Affiliated_investment_to_capital	"Affiliated Investment to Capital";

/* Save data */

sort Years AMB_Number;

save "data\Liquidity Analysis", replace;

log close;
