/* Plots2.do (STATA)
	Plot shadow insurance.
	by Motohiro Yogo. */

#delimit ;
clear all;
set more off;
set scheme s1mono;

cap log close;
log using Plots2, replace;

/* Total shadow insurance */

u data\Company if Years>=2002 & shadow, clear;

collapse (sum) netReserveS As_rep_capital___surplus, by(Years);

gen Share = netReserveS/As_rep_capital___surplus;

l Years netReserveS Share, noobs clean;

label var netReserveS "Reinsurance ceded (billion $)";
label var Share "As share of capital & surplus";

twoway (bar netReserveS Years, yaxis(1) color(gray))
	(line Share Years, yaxis(2) lc(black) lp(solid)),
	ylabel(0(100)400, axis(1) angle(0))
	ylabel(0(.5)3, axis(2) angle(0))
	legend(pos(11) ring(0) col(1));

graph export ..\figures\Shadow.eps, replace;

/* Decomposition of gross reserves */

u data\Company if Years>=2002 & shadow, clear;

collapse (sum) netReserve netReserveS rsv_gross, by(Years);

gen Share3 = netReserveS/rsv_gross;
gen Share2 = netReserve/rsv_gross;
gen Share1 = 1;

l Years Share*, noobs clean;

twoway area Share1 Share2 Share3 Years,
	color(ltblue midblue blue)
	ylabel(0(.2)1, angle(0))
	ytitle("Share of gross reserves")
	legend(label(1 "Net reserves") label(2 "Ceded to other reinsurers") label(3 "Ceded to shadow reinsurers")
	pos(11) ring(0) col(1));

graph export ..\figures\Reserve.eps, replace;

/* Shadow vs. unaffiliated reinsurance */

u data\Reinsurance if ceded, clear;

gen netReserveS = netReserve if shadow;
gen netReserveU = netReserve if !affiliated;

collapse (sum) netReserveS netReserveU, by(Years);

l Years netReserveS netReserveU, noobs clean;

twoway (line netReserveS Years, lc(black) lp(solid))
	(line netReserveU Years, lc(black) lp(dash)),
	ylabel(0(100)400, angle(0))
	ytitle("Reinsurance ceded (billion $)")
	legend(label(1 "Shadow") label(2 "Third-party")
	pos(11) ring(0) col(1));

graph export ..\figures\Comparison.eps, replace;


/* Life insurance premiums */

u data\Company if Years>=2002, clear;

collapse (mean) markup, by (Years shadow);

twoway (line markup Years if !shadow, lc(black) lp(dash))
	(line markup Years if shadow, lc(black) lp(solid)),
	ylabel(1.4(.1)1.9, angle(0))
	ytitle("Premium (per $1 actuarial value)")
	legend(label(1 "No") label(2 "Yes") order(- "Using shadow insurance:" 1 2)
	pos(5) ring(0) col(1));

sort shadow Years;
l shadow Years markup, noobs clean;

graph export ..\figures\Premiums.eps, replace;

log close;
