/* Profitability Analysis.do (STATA)
	Merge different years of A.M. Best's Profitability Analysis.
	by Motohiro Yogo */

#delimit ;
clear all;
set more off;

cap log close;
log using "Profitability Analysis", replace;

/* 2003 */

u "data\2003\Profitability Analysis", clear;

save "data\Profitability Analysis", replace;

/* 2004-2013 */

forval y = 2004/2013 {;
	u "data\\`y'\Profitability Analysis"
		if Years==string(`y'-1), clear;

	append using "data\Profitability Analysis";

	save "data\Profitability Analysis", replace;
};

/* Fix variables */

gen AMB_Number = substr(Companies,1,6);
gen AMB_Company_Name = ltrim(rtrim(itrim(substr(Companies,7,.))));

destring Years AMB_Number, replace;

drop Companies;

/* Label variables */

order Years AMB_Number AMB_Company_Name;

label var Years							 	"Year";
label var AMB_Number						"AMB Company Number";
label var AMB_Company_Name					"AMB Company Name";

label var Benefits_paid_to_npw				"Benefits Paid to NPW";
label var Commissions___expenses_to_npw		"Commissions & Expenses to NPW";
label var Net_operating_gain_to_total_asse	"Net Operating Gain to Total Assets";
label var Net_operating_gain_to_total_reve	"Net Operating Gain to Total Revenue";
label var Return_on_equity					"Return on Equity";
label var Net_yield							"Net Yield";
label var Total_return						"Total Return";

/* Save data */

sort Years AMB_Number;

save "data\Profitability Analysis", replace;

log close;
