/* Ratings.do (STATA)
	Relation between ratings and shadow insurance. 
	by Motohiro Yogo. */

#delimit ;
clear all;
set more off;

cap log close;
log using Ratings, replace;

u data\Company if Years>=2002 & regexm(Best_s_FSR,"^(A|B|C|D)") & Financial_Size>0, clear;

/* Create variables */

egen _LNliabilities = std(LNliabilities);
egen _leverage = std(leverage);
egen _Best_s_Capital = std(Best_s_Capital_Adequacy_Ratio);
egen _Current_liquidity = std(Current_liquidity);
egen _Return_on_equity = std(Return_on_equity);
egen _Guideline = std(Guideline);
egen _stock_SIn_frc1 = std(stock_SIn_frc1);

gen _LNliabilities2 = _LNliabilities^2;
gen _leverage2 = _leverage^2;
gen _Best_s_Capital2 = _Best_s_Capital^2;
gen _Current_liquidity2 = _Current_liquidity^2;
gen _Return_on_equity2 = _Return_on_equity^2;

char Years[omit] 2012;
char Financial_Size[omit] 15;
char AMB_Financial_Group_Number[omit] 70192; 

/* Ratings: OLS */

xi: qui reg _Guideline shadow
	i.Financial_Size i.Years
	if LNliabilities<.,
	vce(cluster AMB_Financial_Group_Number);
eststo;

xi: qui reg _Guideline shadow
	_LNliabilities _Best_s_Capital _leverage _Current_liquidity _Return_on_equity stock
	i.Financial_Size i.Years,
	vce(cluster AMB_Financial_Group_Number);
eststo;

xi: qui reg _Guideline shadow
	_LNliabilities _Best_s_Capital _leverage _Current_liquidity _Return_on_equity stock
	_LNliabilities2 _Best_s_Capital2 _leverage2 _Current_liquidity2 _Return_on_equity2
	i.Financial_Size i.Years,
	vce(cluster AMB_Financial_Group_Number);
eststo;

/* Ratings: IV */

xi: qui reg shadow _stock_SIn_frc1
	_LNliabilities _Best_s_Capital _leverage _Current_liquidity _Return_on_equity stock
	i.Financial_Size i.Years if Guideline<.,
	vce(cluster AMB_Financial_Group_Number);
eststo;

xi: qui ivregress liml _Guideline (shadow = _stock_SIn_frc1)
	_LNliabilities _Best_s_Capital _leverage _Current_liquidity _Return_on_equity stock
	i.Financial_Size i.Years,
	vce(cluster AMB_Financial_Group_Number);
eststo;

/* BCAR: OLS */

xi: qui reg _Best_s_Capital shadow
	_LNliabilities _leverage _Current_liquidity _Return_on_equity stock
	i.Financial_Size i.Years,
	vce(cluster AMB_Financial_Group_Number);
eststo;

/* Output table */

esttab, b(%8.4f) se(%8.4f) r2(%8.4f) nostar nopa nogaps
	keep(shadow _stock_SIn_frc1
	_LNliabilities _Best_s_Capital _leverage _Current_liquidity _Return_on_equity stock
	_LNliabilities2 _Best_s_Capital2 _leverage2 _Current_liquidity2 _Return_on_equity2)
	order(shadow _stock_SIn_frc1
	_LNliabilities _Best_s_Capital _leverage _Current_liquidity _Return_on_equity stock);
eststo clear;


/* Check the exclusion restriction in 1999 */

u data\Company if Years<=2000 & regexm(Best_s_FSR,"^(A|B|C|D)") & Financial_Size>0, clear;

sort AMB_Number Years;
by AMB_Number: replace Best_s_Capital_Adequacy_Ratio = Best_s_Capital_Adequacy_Ratio[_n+1] if Years==1999;

keep if Years==1999;

/* Create variables */

egen _LNliabilities = std(LNliabilities);
egen _leverage = std(leverage);
egen _Best_s_Capital = std(Best_s_Capital_Adequacy_Ratio);
egen _Current_liquidity = std(Current_liquidity);
egen _Return_on_equity = std(Return_on_equity);
egen _Guideline = std(Guideline);
egen _SIn_frc_end_yr_amt = std(SIn_frc_end_yr_amt);

char Financial_Size[omit] 15;
char AMB_Financial_Group_Number[omit] 70192; 

/* Ratings: OLS */

xi: qui reg _Guideline
	_SIn_frc_end_yr_amt _LNliabilities _Best_s_Capital _leverage _Current_liquidity _Return_on_equity stock
	i.Financial_Size,
	vce(cluster AMB_Financial_Group_Number);
eststo;

/* Output table */

esttab, b(%8.4f) se(%8.4f) r2(%8.4f) nostar nopa nogaps
	keep(_SIn_frc_end_yr_amt _LNliabilities _Best_s_Capital _leverage _Current_liquidity _Return_on_equity stock)
	order(_SIn_frc_end_yr_amt _LNliabilities _Best_s_Capital _leverage _Current_liquidity _Return_on_equity stock);

log close;
