/* Reinsurance.do (STATA)
	Construct reinsurance data by contract.
	by Motohiro Yogo. */

#delimit ;
clear all;
set more off;

cap log close;
log using Reinsurance, replace;

/* Merge Schedule S Parts 3.1 & 1.1 */

u "data\Schedule S Part 3.1.dta", clear;

gen byte ceded = 1;

append using "data\Schedule S Part 1.1.dta";

recode authorized (.=1);
recode ceded (.=0);

/* Fix variables */

replace AMB_Financial_Group_Name = AMB_Company_Name if AMB_Financial_Group_Name=="" & Aggregation_Code__AMB=="U";
replace AMB_Financial_Group_Number = AMB_Number if AMB_Financial_Group_Number==. & Aggregation_Code__AMB=="U";

replace AMB_Reinsurer_Financial_Group_Na = AMB_Reinsurer_Company_Name if AMB_Reinsurer_Financial_Group_Na=="" & Aggregation_Code__Rein=="U";
replace AMB_Reinsurer_Financial_Group_Nu = AMB_Reinsurer_Company_Number if AMB_Reinsurer_Financial_Group_Nu==. & Aggregation_Code__Rein=="U";

replace Best_s_Rating___Current__AMB = rtrim(regexr(Best_s_Rating___Current__AMB,"(gu|pd|pu|ru|g|p|r|s|u|-[1-5])$",""));
replace Best_s_Rating___Current__AMB = regexr(Best_s_Rating___Current__AMB,"^$","NR");

replace Best_s_Rating___Current__Rein = rtrim(regexr(Best_s_Rating___Current__Rein,"(gu|pd|pu|ru|g|p|r|s|u|-[1-5])$",""));
replace Best_s_Rating___Current__Rein = regexr(Best_s_Rating___Current__Rein,"^$","NR");

replace State = regexr(State,"AL","Alabama");
replace State = regexr(State,"AR","Arkansas");
replace State = regexr(State,"AZ","Arizona");
replace State = regexr(State,"CA","California");
replace State = regexr(State,"CO","Colorado");
replace State = regexr(State,"CT","Connecticut");
replace State = regexr(State,"DC","District of Columbia");
replace State = regexr(State,"DE","Delaware");
replace State = regexr(State,"FL","Florida");
replace State = regexr(State,"GA","Georgia");
replace State = regexr(State,"GU","Guam");
replace State = regexr(State,"HI","Hawaii");
replace State = regexr(State,"IA","Iowa");
replace State = regexr(State,"ID","Idaho");
replace State = regexr(State,"IL","Illinois");
replace State = regexr(State,"IN","Indiana");
replace State = regexr(State,"KS","Kansas");
replace State = regexr(State,"KY","Kentucky");
replace State = regexr(State,"LA","Louisiana");
replace State = regexr(State,"MA","Massachusetts");
replace State = regexr(State,"MD","Maryland");
replace State = regexr(State,"ME","Maine");
replace State = regexr(State,"MI","Michigan");
replace State = regexr(State,"MN","Minnesota");
replace State = regexr(State,"MO","Missouri");
replace State = regexr(State,"MS","Mississippi");
replace State = regexr(State,"MT","Montana");
replace State = regexr(State,"NC","North Carolina");
replace State = regexr(State,"ND","North Dakota");
replace State = regexr(State,"NE","Nebraska");
replace State = regexr(State,"NH","New Hampshire");
replace State = regexr(State,"NJ","New Jersey");
replace State = regexr(State,"NV","Nevada");
replace State = regexr(State,"NY","New York");
replace State = regexr(State,"OH","Ohio");
replace State = regexr(State,"OK","Oklahoma");
replace State = regexr(State,"OR","Oregon");
replace State = regexr(State,"PA","Pennsylvania");
replace State = regexr(State,"PR","Puerto Rico");
replace State = regexr(State,"RI","Rhode Island");
replace State = regexr(State,"SC","South Carolina");
replace State = regexr(State,"SD","South Dakota");
replace State = regexr(State,"TN","Tennessee");
replace State = regexr(State,"TX","Texas");
replace State = regexr(State,"UT","Utah");
replace State = regexr(State,"VA","Virginia");
replace State = regexr(State,"VT","Vermont");
replace State = regexr(State,"WA","Washington");
replace State = regexr(State,"WI","Wisconsin");
replace State = regexr(State,"WY","Wyoming");

replace Domicile = regexr(Domicile,"British Virgin Islan|British Virgin Isles","British Virgin Islands");
replace Domicile = regexr(Domicile,"Channel isles","Channel Isles");
replace Domicile = regexr(Domicile,"Hong Kong, Special A","Hong Kong");
replace Domicile = regexr(Domicile,"Russian Federation","Russia");
replace Domicile = regexr(Domicile,"Island of Nevis|Saint Kitts and Nevi|St. Kitts-Nevis","St. Kitts & Nevis");
replace Domicile = regexr(Domicile,"Korea, Republic of","South Korea");
replace Domicile = regexr(Domicile,"Saint Vincent and Gr|St. Vincent & Grenad|St.Vincent&Granadine|St.Vincent&Grenadine","St. Vincent & Grenadine");
replace Domicile = regexr(Domicile,"Taiwan, Republic of","Taiwan");
replace Domicile = regexr(Domicile,"Trinidad and Tobago","Trinidad & Tobago");
replace Domicile = regexr(Domicile,"Turks and Caicos Isl","Turks & Caicos");
replace Domicile = regexr(Domicile,"Unkown","Unknown");
replace Domicile = regexr(Domicile,"Venezuela, Bolivaria","Venezuela");
replace Domicile = regexr(Domicile,"WI","Wisconsin");

replace Type = regexr(Type,"//|\\|\.+|\?","/");

replace Type = regexr(Type,"^(CO/INS$|CO/L$|COI$|COI/|COINS$|COINS/|COINSURA$|LAH/CO$|\LAH-CO$|LAH-COIN$)","CO/");
replace Type = regexr(Type,"(/CO/I|/COIN)$","/CO");
replace Type = regexr(Type,"^(CFW/|COWF/|CPFW/)","COFW/");
replace Type = regexr(Type,"^(CM/|MOC/|MOD/|MODCO$|MODCO/|LAH-MC$)","MCO/");
replace Type = regexr(Type,"(/MOD|/MODCO)$","/MCO");
replace Type = regexr(Type,"^(COMCO/)","COMB/");
replace Type = regexr(Type,"^(AYRT/|MRT$|MRT/|RT/|TRT/|YRL/|YRY/|YTR/|LAH-YR$)","YRT/");
replace Type = regexr(Type,"^(AT/|CATI$|CLASH/)","CAT/");
replace Type = regexr(Type,"^(O$|O/|OO/|OTH/A/|OTH/L/|OTHER$|OTHER/|OTHI$|TH/|LAH-OT$)","OTH/");
replace Type = regexr(Type,"(/O)$","/OTH");

replace Type = regexr(Type,"^(AC$|AC/|CO/A$|COA/|LAH-AC$|LAH-AM$|LAH-AN$)","ACO/");
replace Type = regexr(Type,"^(COAFW/)","ACOFW/");
replace Type = regexr(Type,"^(AM/CO/|AM/|AMC/|AMCI/|MACO/)","AMCO/");
replace Type = regexr(Type,"^(ABD/|LAH-AD$)","ADB/");
replace Type = regexr(Type,"^(DB/|LAH-DI$)","DIS/");

replace Type = regexr(Type,"^(/|`|~|ADD&)","");
replace Type = regexr(Type,"(/|/ER|/ERR|/F|\(GC|/I/G|/I&G|/IPO|/L|/PO|/UL|\(UL\))$","");
replace Type = regexr(Type,"^(A|C|D|G|M|Y|C/I|GP|GPO|GPO/I|LPR/I|M/I|MIX/I|SSL/L/I|T/G)$","");
replace Type = regexr(Type,"^(ANNUITY|COLOGNE,|EXCESS|GROUPAN|HAMILTON|HARTFORD|STOPLOS|WILMINGT)$","");
replace Type = regexr(Type,"(/G-)$","/G");

/* Create reinsurer identifier */

gen amb_reinsurer_company_name = lower(AMB_Reinsurer_Company_Name);

sort AMB_Reinsurer_Company_Number Domicile amb_reinsurer_company_name Years;
by AMB_Reinsurer_Company_Number Domicile: replace amb_reinsurer_company_name = amb_reinsurer_company_name[_N]
	if AMB_Reinsurer_Company_Number<.;

replace amb_reinsurer_company_name = subinstr(amb_reinsurer_company_name,".","",.);
replace amb_reinsurer_company_name = subinstr(amb_reinsurer_company_name,","," ",.);

replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," (co|company)( |$)"," ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," (inc|incorporated)$","");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," (limited|ltd)$","");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," llc$","");

replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," 1( |$)"," i ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," and "," & ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," ann( |$)"," annuity ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," assoc( |$)"," association ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," assur( |$)"," assurance ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"\((bermuda|bm)\)"," ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"\(cayman\)"," ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," fin( |$)"," financial ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," grp( |$)"," group ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," ins( |$)"," insurance ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," intl( |$)"," international ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"\(ireland\)"," ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," mut( |$)"," mutual ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," natl( |$)"," national ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," (reas|reassur)( |$)"," reassurance ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," (re|rein|reins|reinsurnace)( |$)"," reinsurance ");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," svcs( |$)"," services ");

replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," amer$"," america");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," (s carlina|south carolina)$"," sc");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name," vermont$"," vt");

replace amb_reinsurer_company_name = ltrim(rtrim(itrim(amb_reinsurer_company_name)));

replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^aig vie$","aig vie france");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^allianz life of missouri$","allianz life insurance of mo");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^american security life \(ticino\)$","american security life");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^aviva reinsurance$","aviva reinsurance usa");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^axa cessions \(axa schade nv\)$","axa cessions");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^first great west life & annuity insurance$","first great-west l & a insurance");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^(great west life & annuity insurance of south|great west life sc)$","great-west life & annuity insurance of sc");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^hellenic-alico life insurance sa$","hellenic alico life insurance");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^malaysian life reinsurance group bhd$","malaysian life reinsurance group berhad");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^mass mutual$","massmutual");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^mo reinsurance \(barbados\)$","missouri reinsurance (barbados)");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^new york life worldwide$","new york life insurance worldwide");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^nfre$","nf reinsurance");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^pre reinsurance$","preferred reinsurance");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^rivermont insurance i$","rivermont life insurance i");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^sun life financial insurance & annuity$","sun life financial insurance annuity");
replace amb_reinsurer_company_name = regexr(amb_reinsurer_company_name,"^voluntary employees' benefit association$","voluntary employee's benefit association");

sort Years amb_reinsurer_company_name Domicile AMB_Reinsurer_Company_Number;
by Years amb_reinsurer_company_name Domicile: replace AMB_Reinsurer_Company_Number = AMB_Reinsurer_Company_Number[1];
by Years amb_reinsurer_company_name Domicile: replace Best_s_Rating___Current__Rein = Best_s_Rating___Current__Rein[1];

/* Create variables */

gen byte captive = affiliated & Best_s_Rating___Current__Rein=="NR";	/* DEFINITION */
gen byte shadow = captive & !authorized;

gen byte usDomicile = 0;
replace usDomicile = 1 if regexm(Domicile,"Alabama|Alaska|Arizona|Arkansas|California|Colorado|Connecticut|Delaware|Florida|Georgia");
replace usDomicile = 1 if regexm(Domicile,"Hawaii|Idaho|Illinois|Indiana|Iowa|Kansas|Kentucky|Louisiana|Maine|Maryland");
replace usDomicile = 1 if regexm(Domicile,"Massachusetts|Michigan|Minnesota|Mississippi|Missouri|Montana|Nebraska|Nevada|New Hampshire|New Jersey");
replace usDomicile = 1 if regexm(Domicile,"New Mexico|New York|North Carolina|North Dakota|Ohio|Oklahoma|Oregon|Pennsylvania|Rhode Island|South Carolina");
replace usDomicile = 1 if regexm(Domicile,"South Dakota|Tennessee|Texas|Utah|Vermont|Virginia|Washington|West Virginia|Wisconsin|Wyoming");
replace usDomicile = 1 if regexm(Domicile,"District of Columbia|American Samoa|Guam|Puerto Rico|U.S. Virgin Islands");

gen category = "Life" if regexm(Type,"^(CO|MCO|YRT|ADB)");
replace category = "Annuity" if regexm(Type,"^(ACO|AMCO|GMDB)");

gen int effectYears = Years-year(Effective_Date);

egen minYears = min(Years), by(AMB_Number amb_reinsurer_company_name Domicile Effective_Date Type
	affiliated genaccount authorized ceded);
gen byte first = Years==minYears & effectYears<=1;
drop minYears;

gen netPremiums = Premiums if ceded;
replace netPremiums = -Premiums if !ceded;

gen netReserve = Reserve_Credit_Taken___Current+Modified_Coinsurance_Reserve if ceded;
replace netReserve = -(Reserve+Modified_Coinsurance_Reserve) if !ceded;

gen price = netPremiums/netReserve if Premiums>0;

/* Screening criteria */

drop if Domicile=="Unknown";
drop if category=="";
drop if effectYears<0;

drop if Reserve_Credit_Taken___Current<0;
drop if Modified_Coinsurance_Reserve<0;
drop if Reserve<0;

/* Save data */

sort Years AMB_Number AMB_Reinsurer_Company_Number amb_reinsurer_company_name Domicile Section Line ceded;

compress;

save data\Reinsurance, replace;


/* List of affiliated reinsurers */

u data\Reinsurance if affiliated, clear;

sort amb_reinsurer_company_name Domicile AMB_Reinsurer_Company_Number Years;
by amb_reinsurer_company_name Domicile: keep if _n==1;

outsheet amb_reinsurer_company_name Domicile AMB_Reinsurer_Company_Number Years
	using data\Reinsurance.csv, comma replace;

log close;
