/* Schedule S Part 3.1.do (STATA)
	Merge different years of A.M. Best's Schedule S Part 3.1.
	by Motohiro Yogo. */

#delimit ;
clear all;
set more off;

cap log close;
log using "Schedule S Part 3.1.smcl", replace;

/* Unauthorized companies from Schedule S Part 4 */

u Years AMB_Number AMB_Reinsurer_Company_Name__Rein AMB_Reinsurer_Company_Number__Re
	NAIC_Company_Number__Rein_Core_ Domicile_Jurisdiction__Rein_Core part31
	if part31
	using "data\Schedule S Part 4", clear;

drop part31;

duplicates drop;

tempfile Unauthorized;
save `Unauthorized';

/* 2003 */

u A_M__Best_Company_Name A_M__Best_Company_Number A_M__Best_Group_Name__AMB_Core_ A_M__Best_Group_Number__AMB_Core
	NAIC_Company_Number__AMB_Core_ NAIC_Group_Number__AMB_Core_
	Aggregation_Code__AMB_Core_ Current_Best_s_Rating__AMB_Core_ State_of_Domicile__AMB_Core_	
	Reinsurer_Reinsured_Name__Rein_C A_M__Best_Reinsurer_Company_Numb A_M__Best_Reinsurer_Group_Name_ A_M__Best_Reinsurer_Group_Number
	NAIC_Company_Number__Rein_Core_ NAIC_Group_Number__Rein_Core_
	Aggregation_Code__Rein_Core_ Current_Best_s_Rating__Rein_Core Domicile_Jurisdiction__Rein_Core
	Name_of_Reinsurer Effective_Date Type_of_Reinsurance_Ceded 
	Amount_in_Force_at_End_of_Year 
	Reserve_Credit_Taken___Current_Y Reserve_Credit_Taken___Prior_Yea Premiums              
	Outstanding_Surplus_Relief___Cur Outstanding_Surplus_Relief___Pri 
	Modified_Coinsurance_Reserve Funds_Withheld_Under_Coinsurance
	Section Line_Number
	using "data\2003\2003 schedule s part 3.1.dta", clear;

gen int Years = 2002;

rename Current_Best_s_Rating__AMB_Core_ Best_s_Rating___Current__AMB_Cor;
rename Reinsurer_Reinsured_Name__Rein_C AMB_Reinsurer_Company_Name__Rein;
rename Current_Best_s_Rating__Rein_Core Best_s_Rating___Current__Rein_Co;

destring Amount_in_Force_at_End_of_Year, replace;
destring Reserve_Credit_Taken___Current_Y, replace;
destring Reserve_Credit_Taken___Prior_Yea, replace;
destring Premiums, replace;
destring Outstanding_Surplus_Relief___Cur, replace;
destring Outstanding_Surplus_Relief___Pri, replace;
destring Modified_Coinsurance_Reserve, replace;
destring Funds_Withheld_Under_Coinsurance, replace;
	
save "data\Schedule S Part 3.1.dta", replace;

/* 2004 */

u A_M__Best_Company_Name A_M__Best_Company_Number A_M__Best_Group_Name__AMB_Core_ A_M__Best_Group_Number__AMB_Core
	NAIC_Company_Number__AMB_Core_ NAIC_Group_Number__AMB_Core_
	Aggregation_Code__AMB_Core_ Best_s_Rating___Current__AMB_Cor State_Jurisdiction_of_Domicile_
    A_M__Best_Reinsurer_Company_Name A_M__Best_Reinsurer_Company_Numb A_M__Best_Reinsurer_Group_Name_ A_M__Best_Reinsurer_Group_Number
	NAIC_Company_Number__Rein_Core_ NAIC_Group_Number__Rein_Core_
	Aggregation_Code__Rein_Core_ Best_s_Rating___Current__Rein_Co Domicile_of_Jurisdiction__Rein_C
	Name_of_Reinsurer Effective_Date Type_of_Reinsurance_Ceded 
	Amount_in_Force_at_End_of_Year 
	Reserve_Credit_Taken___Current_Y Reserve_Credit_Taken___Prior_Yea Premiums              
	Outstanding_Surplus_Relief___Cur Outstanding_Surplus_Relief___Pri 
	Modified_Coinsurance_Reserve Funds_Withheld_Under_Coinsurance
	Section Line_Number
	using "data\2004\2004 schedule s part 3.1.dta", clear;

gen int Years = 2003;

rename State_Jurisdiction_of_Domicile_ State_of_Domicile__AMB_Core_;
rename A_M__Best_Reinsurer_Company_Name AMB_Reinsurer_Company_Name__Rein;
rename Domicile_of_Jurisdiction__Rein_C Domicile_Jurisdiction__Rein_Core;

tostring A_M__Best_Group_Number__AMB_Core, replace;
tostring NAIC_Company_Number__AMB_Core_, replace;
tostring NAIC_Group_Number__AMB_Core_, replace;
tostring A_M__Best_Reinsurer_Group_Number, replace;
tostring NAIC_Company_Number__Rein_Core_, replace;
tostring NAIC_Group_Number__Rein_Core_, replace;

append using "data\Schedule S Part 3.1.dta";

rename Line_Number Line;

save "data\Schedule S Part 3.1.dta", replace;

/* 2005-2008 */

forval y = 2005/2008 {;
	u A_M__Best_Company_Name A_M__Best_Company_Number A_M__Best_Group_Name__AMB_Core_ A_M__Best_Group_Number__AMB_Core
		NAIC_Company_Number__AMB_Core_ NAIC_Group_Number__AMB_Core_
		Aggregation_Code__AMB_Core_ Best_s_Rating___Current__AMB_Cor State_of_Domicile__AMB_Core_
		A_M__Best_Reinsurer_Company_Name A_M__Best_Reinsurer_Company_Numb A_M__Best_Reinsurer_Group_Name_ A_M__Best_Reinsurer_Group_Number
		NAIC_Company_Number__Rein_Core_ NAIC_Group_Number__Rein_Core_
		Aggregation_Code__Rein_Core_ Best_s_Rating___Current__Rein_Co Domicile_Jurisdiction__Rein_Core
		Name_of_Reinsurer Effective_Date Type_of_Reinsurance_Ceded 
		Amount_in_Force_at_End_of_Year 
		Reserve_Credit_Taken___Current_Y Reserve_Credit_Taken___Prior_Yea Premiums              
		Outstanding_Surplus_Relief___Cur Outstanding_Surplus_Relief___Pri 
		Modified_Coinsurance_Reserve Funds_Withheld_Under_Coinsurance
		Section Line
		using "data\\`y'\\`y' schedule s part 3.1.dta", clear;

	gen int Years = `y'-1;

	rename A_M__Best_Reinsurer_Company_Name AMB_Reinsurer_Company_Name__Rein;

	append using "data\Schedule S Part 3.1.dta";
	save "data\Schedule S Part 3.1.dta", replace;
};

/* 2009 */

u A_M__Best_Company_Name A_M__Best_Company_Number A_M__Best_Group_Name__AMB_Core_ A_M__Best_Group_Number__AMB_Core
	NAIC_Company_Number__AMB_Core_ NAIC_Group_Number__AMB_Core_
	Aggregation_Code__AMB_Core_ Best_s_Financial_Strength_Rating State_of_Domicile__AMB_Core_
    A_M__Best_Reinsurer_Company_Name A_M__Best_Reinsurer_Company_Numb A_M__Best_Reinsurer_Group_Name_ A_M__Best_Reinsurer_Group_Number
	NAIC_Company_Number__Rein_Core_ NAIC_Group_Number__Rein_Core_
	Aggregation_Code__Rein_Core_ Best_s_Financial_Strength_Ratin1 Domicile_Jurisdiction__Rein_Core
	Name_of_Reinsurer Effective_Date Type_of_Reinsurance_Ceded 
	Amount_in_Force_at_End_of_Year 
	Reserve_Credit_Taken___Current_Y Reserve_Credit_Taken___Prior_Yea Premiums              
	Outstanding_Surplus_Relief___Cur Outstanding_Surplus_Relief___Pri 
	Modified_Coinsurance_Reserve Funds_Withheld_Under_Coinsurance
	Section Line
	using "data\2009\2009 schedule s part 3.1.dta", clear;

gen int Years = 2008;

rename Best_s_Financial_Strength_Rating Best_s_Rating___Current__AMB_Cor;
rename A_M__Best_Reinsurer_Company_Name AMB_Reinsurer_Company_Name__Rein;
rename Best_s_Financial_Strength_Ratin1 Best_s_Rating___Current__Rein_Co;

append using "data\Schedule S Part 3.1.dta";

rename A_M__Best_Company_Name AMB_Company_Name;
rename A_M__Best_Company_Number AMB_Number;
rename A_M__Best_Group_Name__AMB_Core_ AMB_Financial_Group_Name__AMB_Co;
rename A_M__Best_Group_Number__AMB_Core AMB_Financial_Group_Number__AMB_;
rename A_M__Best_Reinsurer_Company_Numb AMB_Reinsurer_Company_Number__Re;
rename A_M__Best_Reinsurer_Group_Name_ AMB_Reinsurer_Financial_Group_Na;
rename A_M__Best_Reinsurer_Group_Number AMB_Reinsurer_Financial_Group_Nu;

save "data\Schedule S Part 3.1.dta", replace;

/* 2010-2011 */

forval y = 2010/2011 {;
	u AMB_Company_Name AMB_Number AMB_Financial_Group_Name__AMB_Co AMB_Financial_Group_Number__AMB_
		NAIC_Company_Number__AMB_Core_ NAIC_Group_Number__AMB_Core_
		Aggregation_Code__AMB_Core_ Best_s_Financial_Strength_Rating State_of_Domicile__AMB_Core_
		AMB_Reinsurer_Company_Name__Rein AMB_Reinsurer_Company_Number__Re AMB_Reinsurer_Financial_Group_Na AMB_Reinsurer_Financial_Group_Nu
		NAIC_Company_Number__Rein_Core_ NAIC_Group_Number__Rein_Core_
		Aggregation_Code__Rein_Core_ Best_s_Financial_Strength_Ratin4 Domicile_Jurisdiction__Rein_Core
		Name_of_Reinsurer Effective_Date Type_of_Reinsurance_Ceded 
		Amount_in_Force_at_End_of_Year 
		Reserve_Credit_Taken___Current_Y Reserve_Credit_Taken___Prior_Yea Premiums              
		Outstanding_Surplus_Relief___Cur Outstanding_Surplus_Relief___Pri 
		Modified_Coinsurance_Reserve Funds_Withheld_Under_Coinsurance
		Section Line
		using "data\\`y'\\`y' schedule s part 3.1.dta", clear;

	gen int Years = `y'-1;

	rename Best_s_Financial_Strength_Rating Best_s_Rating___Current__AMB_Cor;
	rename Best_s_Financial_Strength_Ratin4 Best_s_Rating___Current__Rein_Co;

	append using "data\Schedule S Part 3.1.dta";
	save "data\Schedule S Part 3.1.dta", replace;
};

/* 2012-2013 */

forval y = 2012/2013 {;
	u AMB_Company_Name AMB_Number AMB_Financial_Group_Name__AMB_Co AMB_Financial_Group_Number__AMB_
		NAIC_Company_Number__AMB_Core_ NAIC_Group_Number__AMB_Core_
		Aggregation_Code__AMB_Core_ Best_s_Financial_Strength_Rating State_of_Domicile__AMB_Core_
		AMB_Reinsurer_Company_Name__Rein AMB_Reinsurer_Company_Number__Re AMB_Reinsurer_Financial_Group_Na AMB_Reinsurer_Financial_Group_Nu
		NAIC_Company_Number__Rein_Core_ NAIC_Group_Number__Rein_Core_
		Aggregation_Code__Rein_Core_ Best_s_Financial_Strength_Ratin5 Domicile_Jurisdiction__Rein_Core
		Name_of_Reinsurer Effective_Date Type_of_Reinsurance_Ceded 
		Amount_in_Force_at_End_of_Year 
		Reserve_Credit_Taken___Current_Y Reserve_Credit_Taken___Prior_Yea Premiums              
		Outstanding_Surplus_Relief___Cur Outstanding_Surplus_Relief___Pri 
		Modified_Coinsurance_Reserve Funds_Withheld_Under_Coinsurance
		Section Line
		using "data\\`y'\\`y' schedule s part 3.1.dta", clear;

	gen int Years = `y'-1;

	rename Best_s_Financial_Strength_Rating Best_s_Rating___Current__AMB_Cor;
	rename Best_s_Financial_Strength_Ratin5 Best_s_Rating___Current__Rein_Co;

	append using "data\Schedule S Part 3.1.dta";
	save "data\Schedule S Part 3.1.dta", replace;
};

/* Fix variables */

replace AMB_Reinsurer_Company_Number = "" if AMB_Reinsurer_Company_Number=="**NA*";

destring AMB_Number, replace;
destring AMB_Financial_Group_Number__AMB_, replace;
destring NAIC_Company_Number__AMB_Core_, replace;

destring AMB_Reinsurer_Company_Number__Re, replace;
destring AMB_Reinsurer_Financial_Group_Nu, replace;
destring NAIC_Company_Number__Rein_Core_, replace;

destring Section, replace;
destring Line, replace;

recode NAIC_Company_Number__AMB_Core_ (0=.);
recode NAIC_Company_Number__Rein_Core_ (0=.);

replace Aggregation_Code__AMB_Core_ = "A" if Aggregation_Code__AMB_Core_=="1";
replace Aggregation_Code__AMB_Core_ = "U" if Aggregation_Code__AMB_Core_=="2";

drop if Aggregation_Code__AMB_Core_=="G" | Aggregation_Code__AMB_Core_=="";

replace Aggregation_Code__Rein_Core_ = "A" if Aggregation_Code__Rein_Core_=="1";
replace Aggregation_Code__Rein_Core_ = "U" if Aggregation_Code__Rein_Core_=="2";

sort AMB_Number Years;
by AMB_Number: replace State_of_Domicile__AMB_Core_ = State_of_Domicile__AMB_Core_[_n-1] if State_of_Domicile__AMB_Core_=="";

gen int date = date(Effective_Date,"MDY");
drop Effective_Date;
rename date Effective_Date;

format %td Effective_Date;

replace Amount_in_Force_at_End_of_Year = Amount_in_Force_at_End_of_Year/1000000000;
replace Reserve_Credit_Taken___Current_Y = Reserve_Credit_Taken___Current_Y/1000000000;
replace Reserve_Credit_Taken___Prior_Yea = Reserve_Credit_Taken___Prior_Yea/1000000000;
replace Premiums = Premiums/1000000000;
replace Outstanding_Surplus_Relief___Cur = Outstanding_Surplus_Relief___Cur/1000000000;
replace Outstanding_Surplus_Relief___Pri = Outstanding_Surplus_Relief___Pri/1000000000;
replace Modified_Coinsurance_Reserve = Modified_Coinsurance_Reserve/1000000000;
replace Funds_Withheld_Under_Coinsurance = Funds_Withheld_Under_Coinsurance/1000000000;
	
/* Create variables */

drop if Line==99999;

gen byte affiliated = 1 if Years<=2005 &
	inlist(Section,1,4);
replace affiliated = 0 if Years<=2005 &
	inlist(Section,2,5);
replace affiliated = 1 if Years>=2006 & Years<=2010 &
	inlist(Section,1,4,8,11);
replace affiliated = 0 if Years>=2006 & Years<=2010 &
	inlist(Section,2,5,9,12);
replace affiliated = 1 if Years==2011 &
	inlist(Section,1,2,8,9,16,17,23,24);
replace affiliated = 0 if Years==2011 &
	inlist(Section,4,5,11,12,19,20,26,27);
replace affiliated = 1 if Years==2012 &
	inlist(Section,1,2,8,9,15,16,23,24,30,31,37,38);
replace affiliated = 0 if Years==2012 &
	inlist(Section,4,5,11,12,18,19,26,27,33,34,40,41);
replace affiliated = 1 if Years>=2013 &
	inlist(Section,1,2,4,5,12,13,15,16,23,24,26,27,35,36,38,39,46,47,49,50,57,58,60,61);
replace affiliated = 0 if Years>=2013 &
	inlist(Section,8,9,19,20,30,31,42,43,53,54,64,65);

gen byte genaccount = 1 if Years<=2005 &
	inlist(Section,1,2);
replace genaccount = 0 if Years<=2005 &
	inlist(Section,4,5);
replace genaccount = 1 if Years>=2006 & Years<=2010 &
	inlist(Section,1,2,4,5);
replace genaccount = 0 if Years>=2006 & Years<=2010 &
	inlist(Section,8,9,11,12);
replace genaccount = 1 if Years==2011 &
	inlist(Section,1,2,4,5,8,9,11,12);
replace genaccount = 0 if Years==2011 &
	inlist(Section,16,17,19,20,23,24,26,27);
replace genaccount = 1 if Years==2012 &
	inlist(Section,1,2,4,5,8,9,11,12,15,16,18,19);
replace genaccount = 0 if Years==2012 &
	inlist(Section,23,24,26,27,30,31,33,34,37,38,40,41);
replace genaccount = 1 if Years>=2013 &
	inlist(Section,1,2,4,5,8,9,12,13,15,16,19,20,23,24,26,27,30,31);
replace genaccount = 0 if Years>=2013 &
	inlist(Section,35,36,38,39,42,43,46,47,49,50,53,54,57,58,60,61,64,65);

gen byte authorized = 1 if Years>=2006 & Years<=2010 &
	inlist(Section,1,2,8,9);
replace authorized = 0 if Years>=2006 & Years<=2010 &
	inlist(Section,4,5,11,12);
replace authorized = 1 if Years==2011 &
	inlist(Section,1,2,4,5,16,17,19,20);
replace authorized = 0 if Years==2011 &
	inlist(Section,8,9,11,12,23,24,26,27);
replace authorized = 1 if Years==2012 &
	inlist(Section,1,2,4,5,23,24,26,27);
replace authorized = 0 if Years==2012 &
	inlist(Section,8,9,11,12,30,31,33,34);
replace authorized = 2 if Years==2012 &
	inlist(Section,15,16,18,19,37,38,40,41);
replace authorized = 1 if Years>=2013 &
	inlist(Section,1,2,4,5,8,9,35,36,38,39,42,43);
replace authorized = 0 if Years>=2013 &
	inlist(Section,12,13,15,16,19,20,46,47,49,50,53,54);
replace authorized = 2 if Years>=2013 &
	inlist(Section,23,24,26,27,30,31,57,58,60,61,64,65);

merge m:1 Years AMB_Number AMB_Reinsurer_Company_Name__Rein AMB_Reinsurer_Company_Number__Re NAIC_Company_Number__Rein_Core_ Domicile_Jurisdiction__Rein_Core using `Unauthorized';

replace authorized = 1 if _merge==1 & Years<=2005;
replace authorized = 0 if _merge==3 & Years<=2005;

drop if _merge==2;
drop _merge;

/* Label variables */

rename Name_of_Reinsurer Name_of_Reinsure;
rename Type_of_Reinsurance_Ceded Type_of_Reinsurance;

order Years
	AMB_Company_Name AMB_Number AMB_Financial_Group_Name__AMB_Co AMB_Financial_Group_Number__AMB_
	NAIC_Company_Number__AMB_Core_ NAIC_Group_Number__AMB_Core_
	Aggregation_Code__AMB_Core_ Best_s_Rating___Current__AMB_Cor State_of_Domicile__AMB_Core_
    AMB_Reinsurer_Company_Name__Rein AMB_Reinsurer_Company_Number__Re AMB_Reinsurer_Financial_Group_Na AMB_Reinsurer_Financial_Group_Nu
	NAIC_Company_Number__Rein_Core_ NAIC_Group_Number__Rein_Core_
	Aggregation_Code__Rein_Core_ Best_s_Rating___Current__Rein_Co Domicile_Jurisdiction__Rein_Core
	Name_of_Reinsure Effective_Date Type_of_Reinsurance
	Amount_in_Force_at_End_of_Year 
	Reserve_Credit_Taken___Current_Y Reserve_Credit_Taken___Prior_Yea Premiums              
	Outstanding_Surplus_Relief___Cur Outstanding_Surplus_Relief___Pri 
	Modified_Coinsurance_Reserve Funds_Withheld_Under_Coinsurance
	Section Line;

label var Years								"Year";

label var AMB_Company_Name					"AMB Company Name";
label var AMB_Number						"AMB Company Number";
label var AMB_Financial_Group_Name__AMB_Co	"AMB Financial Group Name";
label var AMB_Financial_Group_Number__AMB_	"AMB Financial Group Number";
label var NAIC_Company_Number__AMB_Core_	"NAIC Company Number";
label var NAIC_Group_Number__AMB_Core_		"NAIC Group Number";

label var Aggregation_Code__AMB_Core_		"Aggregation Code";
label var Best_s_Rating___Current__AMB_Cor	"Best's Rating Current";
label var State_of_Domicile__AMB_Core_		"State of Domicile";

label var AMB_Reinsurer_Company_Name__Rein	"Reinsurer/Reinsured: AMB Company Name";
label var AMB_Reinsurer_Company_Number__Re	"Reinsurer/Reinsured: AMB Company Number";
label var AMB_Reinsurer_Financial_Group_Na	"Reinsurer/Reinsured: AMB Financial Group Name";
label var AMB_Reinsurer_Financial_Group_Nu	"Reinsurer/Reinsured: AMB Financial Group Number";
label var NAIC_Company_Number__Rein_Core_	"Reinsurer/Reinsured: NAIC Company Number";
label var NAIC_Group_Number__Rein_Core_		"Reinsurer/Reinsured: NAIC Group Number";

label var Aggregation_Code__Rein_Core_		"Reinsurer/Reinsured: Aggregation Code";
label var Best_s_Rating___Current__Rein_Co	"Reinsurer/Reinsured: Best's Rating Current";
label var Domicile_Jurisdiction__Rein_Core	"Reinsurer/Reinsured: Domicile Jurisdiction";

label var Name_of_Reinsure					"Name of Reinsurer/Reinsured";
label var Effective_Date					"Effective Date";
label var Type_of_Reinsurance				"Type of Reinsurance Ceded/Assumed";

label var Amount_in_Force_at_End_of_Year	"Amount in Force at End of Year";

label var Reserve_Credit_Taken___Current_Y	"Reserve Credit Taken Current Year";
label var Reserve_Credit_Taken___Prior_Yea	"Reserve Credit Taken Prior Year";
label var Premiums							"Premiums";

label var Outstanding_Surplus_Relief___Cur	"Outstanding Surplus Relief Current Year";
label var Outstanding_Surplus_Relief___Pri	"Outstanding Surplus Relief Prior Year";

label var Modified_Coinsurance_Reserve		"Modified Coinsurance Reserve";
label var Funds_Withheld_Under_Coinsurance	"Funds Withheld Under Coinsurance";

label var Section							"Section";
label var Line								"Line";

label var affiliated						"1 = Affiliated, 0 = Unaffiliated";
label var genaccount						"1 = General Account, 0 = Separate Account";
label var authorized						"1 = Authorized, 0 = Unauthorized, 2 = Certified";

/* Save data */

compress;

save "data\Schedule S Part 3.1.dta", replace;

log close;
