/* Summary.do (STATA)
	Tabulate summary statistics. 
	by Motohiro Yogo. */

#delimit ;
clear all;
set more off;

cap log close;
log using Summary, replace;

/* Summary of reinsurance agreements */

u data\Reinsurance if ceded & first & netReserve>0, clear;

replace netReserve = 1000*netReserve;

table Years affiliated, c(count netReserve);
table Years if shadow, c(count netReserve);

table Years affiliated, c(mean netReserve);
table Years if shadow, c(mean netReserve);

/* Summary of operating companies */

u data\Company if Years==2012 & regexm(Best_s_FSR,"^(A|B|C|D)") & Financial_Size>0, clear;

tabstat Total_life_ins_rsv_gross Total_annuities_rsv_gross,
	by(shadow) stat(count sum) c(stat);

tabstat stock,
	by(shadow) stat(count mean) c(stat) nototal;

tabstat LNliabilities Guideline Best_s_Capital_Adequacy_Ratio leverage Current_liquidity Return_on_equity, 
	by(shadow) stat(count mean) c(stat) nototal;

/* MetLife's affiliated reinsurance */

u data\Company if Years==2012 & AMB_Financial_Group_Number==70192 & abs(netReserve)>=.1, clear;

gsort -netReserve;
l AMB_Company_Name State Best_s_FSR netReserve, noobs clean;

u data\Reinsurer if Years==2012 & AMB_Financial_Group_Number==70192 & abs(netReserve)>=.1 & !operating, clear;

gsort -netReserve;
l amb_reinsurer_company_name Domicile Best_s_Rating___Current__Rein netReserve authorized, noobs clean;
/*
/* Ranking of shadow insurance by financial group */

u data\Company if Years==2012, clear;

collapse (sum) netReserveS rsv_gross, by(Years AMB_Financial_Group_Number AMB_Financial_Group_Name);

gsort -netReserveS;
l AMB_Financial_Group_Name rsv_gross netReserveS if _n<=20, noobs clean;
*/

/* Risk measures adjusted for shadow insurance */

u data\Company if Years>=2002 & regexm(Best_s_FSR,"^(A|B|C|D)") & Financial_Size>0, clear;

table Years if shadow, c(mean Best_s_Capital_Adequacy_Ratio mean Best_s_CapitalS mean Guideline mean GuidelineS);
table Years if shadow, c(mean Default mean DefaultS);

/* Expected loss adjusted for shadow insurance */

table Years, c(sum loss sum lossS min Capacity);

log close;
