/* Unauthorized.do (STATA)
	Construct data on unauthorized reinsurance.
	by Motohiro Yogo. */

#delimit ;
clear all;
set more off;

cap log close;
log using Unauthorized, replace;

/* Schedule S Part 4 */

u "data\Schedule S Part 4" if part31, clear;

drop part31;

/* Fix variables */

replace AMB_Financial_Group_Name = AMB_Company_Name if AMB_Financial_Group_Name=="" & Aggregation_Code__AMB=="U";
replace AMB_Financial_Group_Number = AMB_Number if AMB_Financial_Group_Number==. & Aggregation_Code__AMB=="U";

replace AMB_Reinsurer_Financial_Group_Na = AMB_Reinsurer_Company_Name if AMB_Reinsurer_Financial_Group_Na=="" & Aggregation_Code__Rein=="U";
replace AMB_Reinsurer_Financial_Group_Nu = AMB_Reinsurer_Company_Number if AMB_Reinsurer_Financial_Group_Nu==. & Aggregation_Code__Rein=="U";

replace Best_s_Rating___Current__AMB = rtrim(regexr(Best_s_Rating___Current__AMB,"(gu|pd|pu|ru|g|p|r|s|u|-[1-5])$",""));
replace Best_s_Rating___Current__AMB = regexr(Best_s_Rating___Current__AMB,"^$","NR");

replace Best_s_Rating___Current__Rein = rtrim(regexr(Best_s_Rating___Current__Rein,"(gu|pd|pu|ru|g|p|r|s|u|-[1-5])$",""));
replace Best_s_Rating___Current__Rein = regexr(Best_s_Rating___Current__Rein,"^$","NR");

replace State = regexr(State,"AL","Alabama");
replace State = regexr(State,"AR","Arkansas");
replace State = regexr(State,"AZ","Arizona");
replace State = regexr(State,"CA","California");
replace State = regexr(State,"CO","Colorado");
replace State = regexr(State,"CT","Connecticut");
replace State = regexr(State,"DC","District of Columbia");
replace State = regexr(State,"DE","Delaware");
replace State = regexr(State,"FL","Florida");
replace State = regexr(State,"GA","Georgia");
replace State = regexr(State,"GU","Guam");
replace State = regexr(State,"HI","Hawaii");
replace State = regexr(State,"IA","Iowa");
replace State = regexr(State,"ID","Idaho");
replace State = regexr(State,"IL","Illinois");
replace State = regexr(State,"IN","Indiana");
replace State = regexr(State,"KS","Kansas");
replace State = regexr(State,"KY","Kentucky");
replace State = regexr(State,"LA","Louisiana");
replace State = regexr(State,"MA","Massachusetts");
replace State = regexr(State,"MD","Maryland");
replace State = regexr(State,"ME","Maine");
replace State = regexr(State,"MI","Michigan");
replace State = regexr(State,"MN","Minnesota");
replace State = regexr(State,"MO","Missouri");
replace State = regexr(State,"MS","Mississippi");
replace State = regexr(State,"MT","Montana");
replace State = regexr(State,"NC","North Carolina");
replace State = regexr(State,"ND","North Dakota");
replace State = regexr(State,"NE","Nebraska");
replace State = regexr(State,"NH","New Hampshire");
replace State = regexr(State,"NJ","New Jersey");
replace State = regexr(State,"NV","Nevada");
replace State = regexr(State,"NY","New York");
replace State = regexr(State,"OH","Ohio");
replace State = regexr(State,"OK","Oklahoma");
replace State = regexr(State,"OR","Oregon");
replace State = regexr(State,"PA","Pennsylvania");
replace State = regexr(State,"PR","Puerto Rico");
replace State = regexr(State,"RI","Rhode Island");
replace State = regexr(State,"SC","South Carolina");
replace State = regexr(State,"SD","South Dakota");
replace State = regexr(State,"TN","Tennessee");
replace State = regexr(State,"TX","Texas");
replace State = regexr(State,"UT","Utah");
replace State = regexr(State,"VA","Virginia");
replace State = regexr(State,"VT","Vermont");
replace State = regexr(State,"WA","Washington");
replace State = regexr(State,"WI","Wisconsin");
replace State = regexr(State,"WY","Wyoming");

replace Domicile = regexr(Domicile,"British Virgin Islan|British Virgin Isles","British Virgin Islands");
replace Domicile = regexr(Domicile,"Channel isles","Channel Isles");
replace Domicile = regexr(Domicile,"Hong Kong, Special A","Hong Kong");
replace Domicile = regexr(Domicile,"Russian Federation","Russia");
replace Domicile = regexr(Domicile,"Island of Nevis|Saint Kitts and Nevi|St. Kitts-Nevis","St. Kitts & Nevis");
replace Domicile = regexr(Domicile,"Korea, Republic of","South Korea");
replace Domicile = regexr(Domicile,"Saint Vincent and Gr|St. Vincent & Grenad|St.Vincent&Granadine|St.Vincent&Grenadine","St. Vincent & Grenadine");
replace Domicile = regexr(Domicile,"Taiwan, Republic of","Taiwan");
replace Domicile = regexr(Domicile,"Trinidad and Tobago","Trinidad & Tobago");
replace Domicile = regexr(Domicile,"Turks and Caicos Isl","Turks & Caicos");
replace Domicile = regexr(Domicile,"Unkown","Unknown");
replace Domicile = regexr(Domicile,"Venezuela, Bolivaria","Venezuela");
replace Domicile = regexr(Domicile,"WI","Wisconsin");

/* Create variables */

gen byte shadow = affiliated & Best_s_Rating___Current__Rein=="NR";	/* DEFINITION */

gen byte usDomicile = 0;
replace usDomicile = 1 if regexm(Domicile,"Alabama|Alaska|Arizona|Arkansas|California|Colorado|Connecticut|Delaware|Florida|Georgia");
replace usDomicile = 1 if regexm(Domicile,"Hawaii|Idaho|Illinois|Indiana|Iowa|Kansas|Kentucky|Louisiana|Maine|Maryland");
replace usDomicile = 1 if regexm(Domicile,"Massachusetts|Michigan|Minnesota|Mississippi|Missouri|Montana|Nebraska|Nevada|New Hampshire|New Jersey");
replace usDomicile = 1 if regexm(Domicile,"New Mexico|New York|North Carolina|North Dakota|Ohio|Oklahoma|Oregon|Pennsylvania|Rhode Island|South Carolina");
replace usDomicile = 1 if regexm(Domicile,"South Dakota|Tennessee|Texas|Utah|Vermont|Virginia|Washington|West Virginia|Wisconsin|Wyoming");
replace usDomicile = 1 if regexm(Domicile,"District of Columbia|American Samoa|Guam|Puerto Rico|U.S. Virgin Islands");

gen int effectYears = Years-year(Effective_Date);

gen Sloc = Letters_of_Credit/(Letters_of_Credit+Trust_Agreements+Funds_Deposited);

/* Screening criteria */

drop if Domicile=="Unknown";
drop if effectYears<0;

drop if Reserve_Credit<0 | Letters_of_Credit<0 | Trust_Agreements<0 | Funds_Deposited<0;

/* Save data */

sort Years AMB_Number AMB_Reinsurer_Company_Number Domicile Section Line;

compress;

save data\Unauthorized, replace;

log close;
