/* gmm_blp.ado (STATA)
	GMM evaluator program for the BLP model.
	by Motohiro Yogo. */

#delimit ;

program gmm_blp;
version 13;

syntax varlist if, at(name) [derivatives(varlist)];
local unobs: word 1 of `varlist';
local shock: word 2 of `varlist';

/* Local variables */

tempvar utility Slife_insTemp elast share1 share2 share diff cost;

local A = 9;

/* Compute mean utility and demand elasticity */

matrix score `utility' = `at' `if', eq(#1);

forval j = 1/100 {;
	qui gen `Slife_insTemp' = 0 `if';
	qui gen `elast' = 0 `if';
	
	forval n = 1/`=Nsim' {;
		qui gen `share1' = exp(`utility'
			+`at'[1,`A'+1]*I_LNlife_ins[`n']*_LNlife_ins+`at'[1,`A'+2]*I_Guideline[`n']*_Guideline+`at'[1,`A'+3]*I_leverage[`n']*_leverage) `if';
		qui egen `share2' = sum(`share1') `if', by(Years);
		qui gen `share' = `share1'/(1+`share2') `if';
		
		qui replace `Slife_insTemp' = `Slife_insTemp'+`share'/Nsim `if';
		qui replace `elast' = `elast'-`at'[1,`A']*`share'*(1-`share')/Nsim `if';
		
		drop `share1' `share2' `share';
	};
	
	qui replace `elast' = markup/Slife_ins*`elast' `if';
	
	/* Check convergence */
	
	qui gen `diff' = ln(Slife_ins)-ln(`Slife_insTemp') `if';
	
	qui sum `diff';
	local Mdiff = max(abs(r(min)),abs(r(max)));
	*di `Mdiff';
	
	/* Update mean utility */
	
	qui replace `utility' = `utility'+`diff' `if';
	
	/* Exit if converged */
	
	if `j'==100 | `Mdiff'<1e-5 {;
		continue, break;
	};
	
	drop `Slife_insTemp' `elast' `diff';
};

/* Compute unobserved characteristic */

matrix score `unobs' = `at' `if', eq(#1) replace;
qui replace `unobs' = `utility'-`unobs' `if';

/* Compute marginal cost */

qui gen `cost' = markup*(1-1/`elast') `if';

matrix score `shock' = `at' `if', eq(#3) replace;
qui replace `shock' = ln(`cost')-`shock' `if';

end;
