/* utility.ado (STATA)
	Compute mean utility, demand elasticity, and marginal cost.
	by Motohiro Yogo. */

#delimit ;

program utility;
version 13;

args b_markup SD_LNlife_ins SD_Guideline SD_leverage;

/* Local variables */

tempvar Slife_insTemp share1 share2 share diff;

/* Compute mean utility and demand elasticity */

forval j = 1/100 {;
	gen `Slife_insTemp' = 0;
	gen elast = 0;
	
	forval n = 1/`=Nsim' {;
		qui gen `share1' = exp(utility
			+`SD_LNlife_ins'*I_LNlife_ins[`n']*_LNlife_ins+`SD_Guideline'*I_Guideline[`n']*_Guideline+`SD_leverage'*I_leverage[`n']*_leverage);
		egen `share2' = sum(`share1'), by(Years);
		qui gen `share' = `share1'/(1+`share2');
		
		qui replace `Slife_insTemp' = `Slife_insTemp'+`share'/Nsim;
		qui replace elast = elast-`b_markup'*`share'*(1-`share')/Nsim;
		
		drop `share1' `share2' `share';
	};
	
	qui replace elast = markup/Slife_ins*elast;
	
	/* Check convergence */
	
	qui gen `diff' = ln(Slife_ins)-ln(`Slife_insTemp');
	
	qui sum `diff';
	local Mdiff = max(abs(r(min)),abs(r(max)));
	*di `Mdiff';
	
	/* Update mean utility */
	
	qui replace utility = utility+`diff';
	
	/* Exit if converged */
	
	if `j'==100 | `Mdiff'<1e-5 {;
		continue, break;
	};
	
	drop `Slife_insTemp' elast `diff';
};

/* Compute marginal cost */

qui gen cost = markup*(1-1/elast);
qui gen LNcost = ln(cost);

end;
